--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2014
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2018
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 23971
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptable range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.62.851' AND '3.62.951')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

-- This is a RunOnce patch - check its not already been applied.
ELSE IF EXISTS(SELECT 1 
	        FROM   sims.db_update_log 
	        WHERE	patch_id = 23971)
  BEGIN
    DECLARE @error_msg1 VARCHAR(100)
    SET @error_msg1 = CHAR(10) + CHAR(13) + 'This patch has already been run on the database and cannot be run again.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg1, 18, 1) 
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1


/*--------------------------------------------------------------------------------------------------------------*/
/* Module     : SIMS Database SQL Server 2008                                                                   */
/* Platform   : Pulsar                                                                                          */
/* Area       : CTF                                                                                             */
/* Copyright  : LegalCopyright (c) Capita Business Services Ltd 1984-2011                                       */
/*            : This code has been written by Capita Education Services for use within its own SIMS systems.    */
/*            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any    */
/*            : means or used without the express written permission of Capita Education Services.              */
/* Status     : REVIEWED				                                                                        */
/*--------------------------------------------------------------------------------------------------------------*/

set nocount on
go

/*--------------------------------------------------------------------------------------------------------------*/
/* Object     : sims.ctf_pix_CTFImport_SaveStudentContactForVersion5                                            */
/*                                                                                                              */
/* Purpose    : To update the student contact details in the database.                                          */
/* Comments   : The Address Format for CTF 5 is different . So this procedure was copied from                   */
/*              ctf_pix_CTFImport_SaveStudentContact so that the earlier versions won't                         */
/*              be affected by the changes                                                                      */
/* Author     : Soawin Poulose                                                                                  */
/* Date       : 07/03/2006                                                                                      */
/*                                                                                                              */  
/* Author     : Mahesh Joshi                                                                                    */
/* Date       : 22/08/2006                                                                                      */
/* Comments   : Modified for RA Impact                                                                          */
/* Modified By: Mahesh Joshi                                                                                    */
/* Modified On: 1/8/6                                                                                           */
/* Comments   : Modified for the CTF 6.0 DUR section 3.9 i.e. Length of contact title is increased to 35        */
/*																												*/
/* Modified by: Abhinav Pandey																				    */
/* Date		  : 1st July 2009																					*/   
/* Comments   : "CTF 9.0 changes"																				*/
/*				Added code to insert/update a contact's email address.										    */
/* Author     : Alan Dean																						*/
/* Date       : 11/08/2009																						*/
/* Purpose    : KB90688: (a) accept either of the tags PostCode and Postcode (lower case c)						*/
/*            :          (b) add postcode to any existing addresses which have no postcode but otherwise match  */
/*            :              ones in the CTF file which do have postcodes (because they may have been lost		*/
/* Updated    : Alan Dean BTR 13/07/09 MINIMUM changes to ensure faulty Pearson CTF files do not cause house	*/
/*              numbers to be lost.																				*/
/*              Disclaimer: no attempt to tidy the code or fix any of the other bugs - that has already been	*/
/*              done for KB85481 / patch 13019																	*/
/*																												*/
/* Updated    : Alan Dean 23/04/2010  OOPS! The above minor tweak did not get replaced by the version from		*/
/*            : the major upgrade of KB85481 once that passed QA, so all the improved address matching and other*/
/*            : fixes from that KB have not been included!  This merges those changes back in.					*/
/*            : Having got that all back together a further change was made for KB97619, to allow Contacts to 	*/
/*            : be imported without students (not quite as daft as it sounds: user may import the CTF file once */
/*            : with the contacts option unticked then again with ONLY the contacts option ticked)				*/
/*																												*/
/* Modified by  : Ashwini Lote																					*/
/* Date	        : 24 Aug 2010																					*/   
/* Description  : CTF 10.0: Calculate of person-id is made inline with other CTF sps, now person_ids are		*/
/*				  evaluated with the use of @PupilsXML XML parameter.											*/
/* By: Chandra S Neelam                                                                                         */
/* Date       : 17 Jan 2011                                                                                     */
/* Details    : KB106416 Fix - Validation changed to import property_easting and property_northing values with  */
/*                                                                                                              */
/*																												*/
/* Updated    : Alan Dean 26/04/2011 & 05/05/2011 KB109467 Strip apostrophes from titles (sims.sims_title       */
/*              forbids them in the code). Also replace comma with space, then double space with single space.  */
/* Updated    : Alan Dean 17/05/2011 Log removal of any invalid postcodes   KB109239                            */
/* Updated    : Alan Dean 30/05/2011 to 28/06/2011 KB109239.                                                    */
/*            : (a) No exception logging if UK country (e.g. England or UK is changed to United Kingdom         */
/*            : (b) Single exception for empty addresses, not pone for each missing part.                       */
/*            : (c) Detecting existing contact: use phone OR address - if contact had no address (or address    */
/*                  in AddressLines format) it always created a duplicate person record.                        */
/*            : (d) DO NOT add new Titles to the Lookup table during import: leave any such titles as null and  */
/*            :     report this in the exception log.                                                           */
/*            : (e) Some code reduction / speed improvements                                                    */
/* Updated    : Alan Dean 08/07/2011 KB110481       Corrected 12/08/2011                                        */
/*            : Update Salutation if user had not previously edited it or if (additional) co-resident parent is */
/*            : imported.  Ditto for parent_address.                                                            */
/*                                                                                                              */
/* Modified by: R Vijayavel                                                                                     */
/* Date       : 18th Aug 2011                                                                                   */
/* Detail     : Modified from "Left Join" to "Inner Join", when set column 'is_applicant' to 'F'                */
/*               in @CTF_PupilData, to avoid crash when import applicants.                                      */
/*                                                                                                              */
/* Modified by: R Vijayavel                                                                                     */
/* Date       : 29 Aug 2011                                                                                     */
/* Detail     : CTF 11: 1. User story 21 - While importing new email address, 'Main' is always set to 'F'.      */
/*                      2. User story 22 - While importing new Fax number, 'Location' is set to 'H' and         */
/*                                         'Main' is set to 'F'.                                                */
/*                      3. Added Surname and Forename in the exception table instead of Preferred Surname and   */
/*                         Preferred Forename.                                                                  */
/* Modified by: Alan Dean                                                                                       */
/* Date       : 07/12/2011                                                                                      */
/* Detail     : KB113881 Improved recognition of complex apartment names and house numbers/names                */

/* Modified by: Alan Dean                                                                                       */
/* Date       : 12/01/2012       IAT977 Easting/Northing  validation (ref KB106416)                             */

/* Modified by: Alan Dean                                                                                       */
/* Date		  : 17/01/2011																						*/
/* Detail     : KB115474   Change the default values for copy_bills to 'F' (studs), and 0 (applicants)			*/

/* Modified by: Mohanish Srivastava                                                                             */
/* Date		  : 11/11/2013																						*/
/* Detail     : Story 41490 : CTF Pupil Link to Contact Already in SIMS											*/
/* Modified by: Jhabiulla Phatan                                                                                */
/* Date		  : 30/04/2014																						*/
/* Detail     : PRB7340																							*/
/*				1.Telephone numbers of one contact have been transferred to another contact with the			*/
/*                same name but unrelated	                                                                    */
/*				2.When two siblings on different CTF files,contact records with no forename in CTF then on      */
/*                Import of both CTFs Student in CTF1 is being assigned as contact for the student in CTF2.     */
/*                                                                                                              */
/* Modified by: Sandeep Kharmate                                                                                */
/* Date       : 08th Jul 2014                                                                                   */
/* Detail     : Story 55529 - Easting & Northing: Change to 3 decimal places.                                   */
/* Modified by : Bala                                                                                            */
/* Date		      : 25/07/2014																						                                                                */
/* Detail      : PRB8041: IF a contact has more than one address types whose enddate is null                     */
/*                          then while importing CTF system crashes. 																							                     */
/*                                                                                                              */
/* Author     : Mike Robinson                                                                                   */
/* Date       : October 2014                                                                                    */
/* Description: Story 62675. Store details of contacts imported during CTF import for reporting on later.       */
/*                                                                                                              */
/* Author     : Seema Dhamale                                                                                   */
/* Date       : 23rd August 2016                                                                                */
/* Description: PBI 151 : 151 - CTF Autumn 2016 Update the import of Contact Title							    */
/*																												*/
/* Author     : Arun Tiwari                                                                                     */
/* Date       : 18th April 2017                                                                                 */
/* Description: 6699 - CTF 17 - Dont import UPRNs that do not have a valid format							    */
/*																												*/
/* Author     : Alan Dean																						*/
/* Date       : 29/1/2017 and 02/04/2017																		*/
/* Description: PRB14843																						*/
/*			  : (a) Valid postcodes were being rejected because the country was Jersey.							*/
/*			  : (b) Another way to determine the contact is an existing person is if they match	on the same     */
/*            :     name criteria as before and have the same relationship to the same applicant or student.	*/
/*			  : (c) If contact is has no title in the CTF we now log a more appropriate exception than			*/
/*			  :     'The title '' was not recognised so has not been imported.'									*/
/*            : (d) Exception log message 'Contact(s) have a priority order of 0 or blank.  Priorities have		*/
/*			  :     been imported as 1.' is shortened, so it may be possible to see it all on screen.			*/
/*																												*/
/* Author     : Tejas Sawant                                                                                    */
/* Date       : 16 Jan 2018															                            */
/* Description: PRB17433 : While importing CTF of leaver student system was ending current address membership	*/
/*				for student and creating new membership with current date if same record is present in			*/
/*  			destination school to avoid duplication. Which was not working properly due to invalid			*/
/*				conditions. Modified the code to handle duplication of membership of student address.			*/
/* Author     : Bala A																							*/
/* Date       : 08 May 2018															                            */
/* Description: PRB18093 :  When importing a CTF, Contact data is overwritten for unrelated Contacts.			*/
/*--------------------------------------------------------------------------------------------------------------*/

exec sims.db_p_comment  'sims.ctf_pix_CTFImport_SaveStudentContactForVersion5'
,                       'sims.ctf_pix_CTFImport_SaveStudentContactForVersion5'
,                       'u'
go

exec sims.db_p_drop     'sims.ctf_pix_CTFImport_SaveStudentContactForVersion5'
,                       'p'
go


Alter procedure sims.ctf_pix_CTFImport_SaveStudentContactForVersion5
(
    @StudentContactsXML text
  , @PupilsXML          text
  , @on_roll            T_pub_logical
)

as

set nocount on

/*--------------------------------------------------------------------------------------------------------------*/
/*                                                                                                              */
/* Results    :                                                                                                 */
/*    -- Records from @CTF_Errors                                                                               */
/*     upn           varchar(13)                                                                                */
/*     surname       varchar(60)                                                                                */
/*     forename      varchar(60)                                                                                */
/*     dob           smalldatetime                                                                              */
/*     gender        varchar(1)                                                                                 */
/*     person_id     int                                                                                        */
/*     errormsg      varchar(200)                                                                               */
/*--------------------------------------------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------------------------------------------*/
/* Parameters :                                                                                                 */
/*                  @StudentContactsXML      Text                                                               */
/*                  @PupilsXML               Text                                                               */
/*                  @on_roll                 T_pub_logical														*/
/*--------------------------------------------------------------------------------------------------------------*/


--- declare local variables
DECLARE 
    @hContactsXmlDoc int
  , @PupilsXmlDoc int 
  , @contact_bit t_pub_tinyint  
  , @contact_aggregate_role int
  , @errorHandle int
  , @UK_countries varchar(150)
  ,	@theUK int
  ,	@default_country_id int
  ,	@start_date smalldatetime
  ,	@prevmaxaddressID int
  ,	@MIV varchar(100)
  , @student_bit smallint  
  , @applicant_bit smallint 
  , @contact_title  varchar(50)
  , @next_order int
  , @parental_addressee_format_type int
  , @ctf_import_id int

set @start_date = convert(smalldatetime, floor(convert(float, getdate())))   -- previous midnight      
select  @parental_addressee_format_type = parental_addressee_format_type -- kb110481
from    sims.sta_setup

DECLARE @contacts table
(
       person_id                        integer
,      upn                              varchar(14)    collate database_default
,      surname                          varchar(60)    collate database_default
,      forename                         varchar(60)    collate database_default
,      preferredSurname                 varchar(60)      collate database_default
,      preferredForename                varchar(60)      collate database_default
,      dob                              smalldatetime
,      gender                           varchar(60)    collate database_default
,      former_upn                       varchar(60)    collate database_default
,      former_surname                   varchar(60)    collate database_default
,      contact_id                       integer
,      priority                         integer
,      title                            varchar(35)    collate database_default
,      contact_surname                  varchar(60)    collate database_default
,      contact_forename                 varchar(60)    collate database_default
,      contact_midname                  varchar(60)    collate database_default
,      contact_gender                   varchar(10)    collate database_default
,      contact_relationship             varchar(10)    collate database_default
,      contact_parent_responsibility    varchar(5)     collate database_default
,      court_order						varchar(1)     collate database_default
,      address_id                       integer  
,      apartment                        varchar(40)    collate database_default
,      SAON								varchar(1000)  collate database_default 
,      flat								varchar(40)    collate database_default
,      PAON								varchar(1000)  collate database_default  			  
,      house_name						varchar(40)    collate database_default
,      house_number						varchar(40)    collate database_default
,      street_description				varchar(40)    collate database_default
,      district							varchar(40)    collate database_default
,      town								varchar(40)    collate database_default
,      county							varchar(40)    collate database_default
,      administrative_area				varchar(100)   collate database_default
,      country							varchar(45)    collate database_default
,      posttown							varchar(40)    collate database_default
,      postcode							varchar(40)    collate database_default
,      postcode2                        varchar(40)    collate database_default  -- KB90688
,	   property_ref_number				varchar(40)    collate database_default
,	   property_easting					varchar(10)    collate database_default
,	   property_northing                varchar(10)    collate database_default
,      zipcode                          varchar(40)    collate database_default
,      postcodeValidUK                  varchar(1)     collate database_default
,      postcodeValidBFPO                varchar(1)     collate database_default
,      match_found						varchar(1)	   collate database_default
,      is_applicant 					char(1)
,	   Email						    varchar(60)    collate database_default null -- CTF 9.0 
,      Empty_address                    bit     --KB109239
)

DECLARE @Phones Table  
(
       person_id                          integer
,      upn                                varchar(14)    collate database_default
,      surname                            varchar(60)    collate database_default
,      forename                           varchar(60)    collate database_default
,      dob                                smalldatetime
,      gender                             varchar(60)    collate database_default
,      former_upn                         varchar(60)    collate database_default
,      former_surname                     varchar(60)    collate database_default
,      contact_id                         integer
,      priority                           integer
,      title                              varchar(35)    collate database_default
,      contact_surname                    varchar(60)    collate database_default
,      contact_forename                   varchar(60)    collate database_default
,      contact_midname                    varchar(60)    collate database_default
,      contact_gender                     varchar(10)    collate database_default
,      contact_relationship               varchar(10)    collate database_default
,      contact_parent_responsibility      varchar(5)        collate database_default
,      court_order						  varchar(1)     collate database_default
,      phone_type                         varchar(1)     collate database_default
,      phone_no                           varchar(35)    collate database_default
)
DECLARE @Address Table
(
       address_id                         integer
,      apartment                          varchar(40)    collate database_default
,      flat                               varchar(40)    collate database_default
,      house_name                         varchar(40)    collate database_default
,      house_number                       varchar(40)    collate database_default
,      street_description                 varchar(40)    collate database_default
,      district                           varchar(40)    collate database_default
,      town                               varchar(40)    collate database_default
,      county                             varchar(40)    collate database_default
,      administrative_area                varchar(100)   collate database_default
,      country                            varchar(45)    collate database_default
,      country_id                         int null
,      postcode                           varchar(40)    collate database_default
,	   property_ref_number                varchar(40)    collate database_default
,	   property_easting                   varchar(10)    collate database_default
,	   property_northing                  varchar(10)    collate database_default
,      zipcode                            varchar(40)    collate database_default
,      posttown                           varchar(30)    collate database_default
,      postcode2                          varchar(40)    collate database_default
,      postcodeValidUK                    varchar(1)     collate database_default
,      postcodeValidBFPO                  varchar(1)     collate database_default
,      external_id                        uniqueidentifier default newid()
)

DECLARE @CTF_Errors Table
(
    upn           varchar(13) collate database_default
  , surname       varchar(60) collate database_default
  , forename      varchar(60) collate database_default
  , dob           smalldatetime
  , gender        varchar(1) collate database_default
  , person_id     int
  , errormsg      varchar(400) collate database_default
)

DECLARE @CTF_PupilData Table
(
    upn					varchar(13) collate database_default
  , surname				varchar(60) collate database_default
  , forename			varchar(60) collate database_default
  , preferredsurname    varchar(60) collate database_default
  , preferredforename   varchar(60) collate database_default
  , dob					smalldatetime
  , gender				varchar(1) collate database_default
  , person_id			int
  , match_found			varchar(1) collate database_default
  , is_applicant		char(1)  
  , num_parents         int  -- KB110481 number of co-resident parents before any (more) are imported 
  , recalc_parent_address  bit
  , recalc_salutation   bit
)

DECLARE @Person  Table
(
  person_id                  integer
, title                      varchar(35)    collate database_default  
, contact_gender             varchar(1)     collate database_default
, contact_surname            varchar(60)    collate database_default
, contact_midname            varchar(60)    collate database_default
, contact_forename           varchar(60)    collate database_default
, external_id                uniqueidentifier    
, address_id                 int
, is_applicant			     char(1)
)

DECLARE @leaver_Pupils TABLE  
(  
 id int  
, surname varchar(60)  
, forename varchar(60)  
, current_year varchar(12)  
, current_reg varchar(12)  
,   year_taught varchar(12)  
, local_upn varchar(20)  
,   uln varchar(10)  
)  
 

DECLARE @Leavers_contacts table  
(  
       person_id                        integer  
,      title                            varchar(35)    collate database_default  
,      upn                              varchar(14)    collate database_default  
,      surname                          varchar(60)    collate database_default  
,      forename                         varchar(60)    collate database_default  
,      preferredSurname                 varchar(60)      collate database_default  
,      preferredForename                varchar(60)      collate database_default  
,      dob                              smalldatetime  
,      gender                           varchar(60)    collate database_default  
,      former_upn                       varchar(60)    collate database_default  
,      former_surname                   varchar(60)    collate database_default  
,      contact_id                       integer
)

  
declare @today smalldatetime,  
        @start_acad_year smalldatetime
        
set @today = getdate()  
-- get the start date of the current academic year      
select @start_acad_year = sims.chk_fnd_acad_year_start(@today)   

INSERT INTO @leaver_Pupils  
(  
 id   
, surname   
, forename  
, current_year  
, current_reg  
, year_taught  
, local_upn  
,   uln  
)  
    Select  per.person_id,  
        per.surname,  
  coalesce(per.chosen_forename, per.forename, ''),  
        IsNull(stu.current_year, ''),  
        IsNull(stu.current_reg, ''),  
     IsNull(stu.current_ncyear, ''),  
     IsNull(stu.unique_pupil_no, ''),  
     isnull(uln.unique_learner_number,'')
       
    from sims.sims_person per inner join sims.stud_student stu on stu.person_id = per.person_id  
        inner join sims.stud_school_history shist on stu.person_id = shist.person_id  
        inner join sims.sims_school sch  on shist.school_id = sch.school_id and sch.status = 'S' -- get students of our school  
        left join sims.sims_person_unique_learner_number uln on stu.person_id = uln.person_id  
    where shist.end_date = (select max(end_date)  
                   from   sims.stud_school_history tsh2 join sims.sims_school ts2  
                   on     tsh2.school_id = ts2.school_id and ts2.status = 'S'  
                   where  shist.person_id = tsh2.person_id  
                   and    end_date < @today --and end_date >= @start_acad_year
                   )  
        and shist.start_date = (select max(start_date)  
                   from   sims.stud_school_history tsh3 join sims.sims_school ts3  
                   on     tsh3.school_id = ts3.school_id and ts3.status = 'S'  
                   where  shist.person_id = tsh3.person_id  
                   and    start_date < @today)        
    order by per.surname, forename, stu.unique_pupil_no     

declare @region varchar(10)

select	@region = reg.region_code
from	sims.sims_region reg
join	sims.db_version_info ver on ver.region_id = reg.region_id


EXEC sp_xml_preparedocument @hContactsXmlDoc OUTPUT, @StudentContactsXML

Insert into @contacts (
    upn
  , surname
  , forename
  , preferredSurname
  , preferredForename
  , dob
  , gender
  , former_upn
  , former_surname
  , priority
  , title
  , contact_surname
  , contact_forename
  , contact_midname
  , contact_gender
  , contact_relationship
  , contact_parent_responsibility
  , court_order
  , SAON
  , apartment
  , flat
  , PAON 
  , house_name
  , house_number
  , street_description
  , district
  , town
  , county
  , administrative_area
  , country
  , posttown
  , postcode
  , postcode2  -- KB90688
  , property_ref_number
  , property_easting
  , property_northing
  , zipcode
  , postcodeValidUK
  , postcodeValidBFPO
-- CTF 9.0 changes  
  , Email
)
SELECT
    upn
  , surname
  , forename
 ,  NULLIF(preferredSurname,'')
  , NULLIF(preferredForename,'')
  , dob
  , gender
  , former_upn
  , former_surname
  , priority
  , rtrim(ltrim(replace(replace(replace(title, ',',' '), '''', ''), '  ', ' '))) -- KB109467 Change comma to space. Remove apostrophe.
  , isnull(contact_surname, '')
  , isnull(contact_forename, '')
  , isnull(contact_midname, '')
  , isnull(contact_gender, '')
  , contact_relationship
  , contact_parent_responsibility
  , court_order
  , SAON
  , apartment
  , flat
  , PAON 
  , house_name
  , house_number
  , street_description
  , district
  , town
  , county
  , administrative_area
  , country
  , posttown
  , postcode
  , postcode2 -- KB90688
  , property_ref_number
  , CASE WHEN (LEN(property_easting) = 7 AND sims.add_fni_Digit_Count(property_easting) = 7)     --KB106416 Fix
         THEN LEFT(property_easting,6)+ '.' + RIGHT(property_easting,1)
         ELSE property_easting
    END
  , CASE WHEN (LEN(property_northing) = 7 AND sims.add_fni_Digit_Count(property_northing) = 7)
         THEN LEFT(property_northing,6)+ '.' + RIGHT(property_northing,1)
         ELSE property_northing
    END
  , zipcode
  ,'F'  
  ,'F'
  
-- CTF 9.0 changes
  , Email

FROM OPENXML(@hContactsXmlDoc,'/Root/StudentContact/Contacts/ContactDetails/Contact')
     WITH (
        upn                                varchar(13)      '../../../MatchTag/@UPN'
      , surname                            varchar(60)      '../../../MatchTag/@Surname'
      , forename                           varchar(60)      '../../../MatchTag/@Forename'
	  , preferredSurname                   varchar(60)      '../../../MatchTag/@PreferredSurname'
      , preferredForename                  varchar(60)      '../../../MatchTag/@PreferredForename'
      , dob                                smalldatetime    '../../../MatchTag/@DOB'
      , gender                             varchar(60)      '../../../MatchTag/@Gender'
      , former_upn                         varchar(60)      '../../../MatchTag/@FormerUPN'
      , former_surname                     varchar(60)      '../../../MatchTag/@FormerSurname'
      , priority                           integer          '@Order'
      , title                              varchar(35)      '@Title'
      , contact_surname                    varchar(60)      '@Surname'
      , contact_forename                   varchar(60)      '@Forename'
      , contact_midname                    varchar(60)      '@MiddleNames'
      , contact_gender                     varchar(1)       '@Gender'
      , contact_relationship               varchar(10)      '@RelationShip'
      , contact_parent_responsibility      varchar(5)       '@Responsibility'
      , court_order						   varchar(1)       '@CourtOrder'
      , SAON							   varchar(1000)    '../Address/@SAON'
      , apartment                          varchar(40)      '../Address/@Apartment'
      , flat                               varchar(40)      '../Address/@Flat'
      , PAON                               varchar(1000)    '../Address/@PAON' -- Added by Lisa for CR23750
      , house_name                         varchar(40)      '../Address/@HouseName'
      , house_number                       varchar(40)      '../Address/@HouseNo'
      , street_description                 varchar(40)      '../Address/@Street'
      , district                           varchar(40)      '../Address/@Locality'
      , town                               varchar(40)      '../Address/@Town'
      , county                             varchar(40)      '../Address/@County'
      , administrative_area                varchar(100)     '../Address/@AdministrativeArea'
      , country                            varchar(45)      '../Address/@Country'
      , posttown						   varchar(40)      '../Address/@PostTown'
      , postcode                           varchar(40)      '../Address/@PostCode'
      , postcode2                          varchar(40)      '../Address/@Postcode'  -- KB90688
	  , property_ref_number                varchar(40)      '../Address/@UniquePropertyReferenceNumber'
	  , property_easting				   varchar(10)      '../Address/@Easting'
	  , property_northing				   varchar(10)      '../Address/@Northing'
      , zipcode                            varchar(40)      '../Address/@ZipCode'
      , Email							   varchar(60)      '@Email'            -- CTF 9.0 changes
)

-- KB90688
update	@contacts 
set		SAON = REPLACE(SAON,'#',' '), 
		PAON = REPLACE(PAON,'#',' '),
		postcode = isnull(postcode, postcode2)


--Added Student level information to Phones table so that students not existing in PupilXML section
--will be deleted from Phones table.
Insert into @Phones (
    upn
  , surname
  , forename
  , dob
  , gender
  , former_upn
  , former_surname
  , priority
  , title
  , contact_surname
  , contact_forename
  , contact_midname
  , contact_gender
  , contact_relationship
  , contact_parent_responsibility
  , court_order
  , phone_type
  , phone_no
)
SELECT
    upn
  , surname
  , forename
  , dob
  , gender
  , former_upn
  , former_surname
  , priority
  , rtrim(ltrim(replace(replace(replace(title, ',',' '), '''', ''), '  ', ' '))) -- KB109467 
  , isnull(contact_surname, '')
  , isnull(contact_forename, '')
  , isnull(contact_midname, '')
  , isnull(contact_gender, '')
  , contact_relationship
  , contact_parent_responsibility
  , court_order
  , phone_type
  , phone_no
FROM OPENXML(@hContactsXmlDoc,'/Root/StudentContact/Contacts/ContactDetails/Phone')
     WITH (
        upn                                varchar(13)      '../../../MatchTag/@UPN'
      , surname                            varchar(60)      '../../../MatchTag/@Surname'
      , forename                           varchar(60)      '../../../MatchTag/@Forename'
      , dob                                smalldatetime    '../../../MatchTag/@DOB'
      , gender                             varchar(60)      '../../../MatchTag/@Gender'
      , former_upn                         varchar(60)      '../../../MatchTag/@FormerUPN'
      , former_surname                     varchar(60)      '../../../MatchTag/@FormerSurname'
      , priority                           integer          '../Contact/@Order'
      , title                              varchar(35)      '../Contact/@Title'
      , contact_surname                    varchar(60)      '../Contact/@Surname'
      , contact_forename                   varchar(60)      '../Contact/@Forename'
      , contact_midname                    varchar(60)      '../Contact/@MiddleNames'
      , contact_gender                     varchar(1)       '../Contact/@Gender'
      , contact_relationship               varchar(10)      '../Contact/@RelationShip'
      , contact_parent_responsibility      varchar(5)       '../Contact/@Responsibility'
      , court_order						   varchar(1)       '../Contact/@CourtOrder'
      , phone_type                         varchar(1)       '@PhoneType'
      , phone_no                           varchar(20)      '@PhoneNo'
)

exec sp_xml_removedocument @hContactsXmlDoc

-- KB97619: If we import ONLY Contacts there will be no person_id values (of the students/applicants) in @contacts
-- so we may need to calculate them here

-- Get the pupil data into @CTF_PupilData table
EXEC sp_xml_preparedocument @PupilsXmlDoc output, @PupilsXML
INSERT INTO @CTF_PupilData (upn, surname, forename,preferredsurname,preferredforename, dob, gender, person_id, match_found)
(SELECT
    upn         
  , surname     
  , forename 
  , preferredsurname   
  , preferredforename
  , dob         
  , gender      
  , person_id   
  , match_found
 FROM OPENXML(@PupilsXmlDoc, '/data/row') 
     WITH (
	      upn      			T_stud_unique_pupil_no  '@UPN'
		, surname			T_pub_personal_name		'@Surname'
		, forename			T_pub_personal_name		'@Forename'
		, preferredsurname  T_pub_personal_name		'@PreferredSurname'
		, preferredforename T_pub_personal_name		'@PreferredForename'
		, dob				T_pub_date				'@DOB'
		, gender			T_pub_gender			'@Gender'
		, person_id			T_pub_foreign_id		'@PersonId'
		, match_found		varchar(1)				'@MatchFound'
	    )

)
EXEC sp_xml_removedocument @PupilsXmlDoc

-- KB85481
UPDATE	@CTF_PupilData set preferredsurname = surname 
WHERE	preferredsurname IS NULL

UPDATE	@CTF_PupilData set preferredforename = forename 
WHERE	preferredforename IS NULL

-- Delete all the pupils for whom the person_id is null
-- We need to keep the existing pupils record as we have to update the records for them. 
DELETE FROM @CTF_PupilData
WHERE person_id IS NULL

SELECT @student_bit = role_bit FROM sims.sims_person_type WHERE description = 'Student'  
  
SELECT @applicant_bit = role_bit FROM sims.sims_person_type WHERE description = 'Applicant'  


-- KB110481 Do not need to recalculate Salutation / Parent_address if user has already changed it from the default calulated value.
update  @CTF_PupilData  
set     recalc_Salutation = 1, 
        recalc_parent_address = 1
        
update  cpd 
set     recalc_Salutation = 0 
from    @CTF_PupilData cpd
join    sims.stud_student ss  
on      ss.person_id = cpd.person_id 
--  treat e.g. 'Mr & Mrs Dean' and  'Mr and Mrs Dean' as the same when deciding if the user has updated the Salutation since it was computed
where   replace(isnull(sims.sta_fnc_getStudent_Salutation_Information (ss.person_id, @start_date), 'X'), '&','and') 
            <> replace(isnull(ss.salutation,'Y'), '&','and')

update cpd  
set    recalc_parent_address = 0   
from   sims.stud_student ss  
join   @CTF_PupilData cpd   
on     ss.person_id = cpd.person_id 
where  replace(isnull(sims.sta_fnc_getStudent_Addressee_Information (ss.person_id, @start_date, @parental_addressee_format_type), 'X'), '&','and') 
         <> replace(isnull(ss.parent_address, 'Y'), '&','and') 
-- Get the person id from the @CTF_PupilData table
UPDATE con
SET	 person_id = cpd.person_id 
	,con.preferredSurname = ISNULL(con.preferredSurname,con.surname)
	,con.preferredForename = ISNULL(con.preferredForename, con.forename)
FROm @contacts con
INNER JOIN @CTF_PupilData cpd
ON cpd.upn = con.upn
AND cpd.surname = con.surname
AND cpd.forename = con.forename
AND cpd.dob = con.dob 
AND cpd.gender = con.gender

-- INSERT ERRORS
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, preferredSurname, preferredForename, dob, gender, person_id, 'Missing Contact Surname'
from	@contacts
where	contact_surname = ''

-- Delete Error Records
delete	@contacts
where	contact_surname = ''

insert  @CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, preferredSurname, preferredForename, dob, gender, person_id, 
		'Contact(s) have a priority order of 0 or blank.  Priorities have been imported as 1.'
		'0 or blank contact priority orders were set to 1.'
from	@contacts
where	isnull(priority, 0) = 0

-- Set priority to 1 if it comes in as 0 or null
update	@contacts
set		priority = 1
where	isnull(priority, 0) = 0


-- KB97619 We still need to populate @CTF_PupilData even if only contacts are being imported this time (and students were imported earlier)
insert	@CTF_PupilData(upn, surname, forename, dob, gender, person_id, match_found)
select	distinct upn, surname, forename, dob, gender, person_id, 'T'
from	@contacts cnt
where   not exists(select 1 from @CTF_PupilData pup where pup.person_id = cnt.person_id)
-- KB97619

-- Delete all the pupils for whom the person_id is null
delete	@CTF_PupilData
where	person_id is null

select	@contact_bit = role_bit from sims.sims_person_type where description = 'Contact'

-- Update the Parental Responsibilty to False, if it is missing.
update	@contacts 
set		contact_parent_responsibility = 'F'
where	Isnull(contact_parent_responsibility, '') in ( '','f', '0', 'FALSE')

-- if the value of a logical variable is 't' or '1' then set it to 'T'; if 'f' or '0' then 'F'
update	@contacts 
set		contact_parent_responsibility = 'T'
where	contact_parent_responsibility in('t', '1', 'TRUE')

update	@Phones
set		contact_parent_responsibility = 'F'
where	Isnull(contact_parent_responsibility, '') in ( '','f', '0', 'FALSE')

-- if the value of a logical variable is 't' or '1' then set it to 'T'; if 'f' or '0' then 'F'
update	@Phones
set		contact_parent_responsibility = 'T'
where	contact_parent_responsibility in( 't','1','TRUE')

-- set all applicant column values to 'F' first.  
UPDATE @CTF_PupilData SET is_applicant = 'F'   
  
-- and update them to 'T' if necessary  
UPDATE @CTF_PupilData   
SET is_applicant = 'T'   
FROM sims.sims_person p   
INNER JOIN @CTF_PupilData ctf   
  ON ctf.person_id = p.person_id   
 AND p.aggregate_role & (power(2,@student_bit)) <= 0  
 AND p.aggregate_role & (power(2,@applicant_bit)) > 0  
	
-- Updating the Person_id of the Valid Students from @CTF_PupilData also set Is_applicant flag to T or F 
update  @contacts
set		person_id = cpd.person_id, match_found = cpd.match_found, is_applicant = cpd.is_applicant    
from	@contacts cts
join	@CTF_PupilData cpd
on		cts.upn      = cpd.upn
and		cts.surname  = cpd.surname
and		cts.forename = cpd.forename
and		cts.gender   = cpd.gender
and		cts.dob      = cpd.dob

-- Updating the Person_id of the Valid Students from @CTF_PupilData
update	@Phones
set		person_id = cpd.person_id
from	@Phones p
join	@CTF_PupilData cpd
on		p.upn      = cpd.upn
and		p.surname  = cpd.surname
and		p.forename = cpd.forename
and		p.gender   = cpd.gender
and		p.dob      = cpd.dob

-- Delete all the pupils with 'null' person_id
delete from @contacts
where person_id is null

-- Delete all the pupils with 'null' person_id and person not selected in Pupil XML section will be deleted
delete from @Phones
where person_id is null

exec sp_xml_preparedocument @errorHandle output, @StudentContactsXML
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, surname, forename, dob, gender, person_id, error
from	openxml(@errorHandle, 'Root/Errors/Error') 
WITH  (	upn         varchar(13)     '@UPN'
	  , surname     varchar(60)     '@PreferredSurname' 
	  , forename    varchar(60)     '@PreferredForename'  
	  , dob         smalldatetime   '@DOB'   
	  , gender      varchar(1)      '@Gender'  
	  , person_id   varchar(40)     '@person_id'  
	  , error       varchar(100)    '@ErrorMsg'     
      ) 
	              
exec sp_xml_removedocument @errorHandle

-- Format postcode, trim country names
update	@contacts
set		PostCode = sims.add_fnc_PCtidy(PostCode),
		country = ltrim(rtrim(isnull(country,'')))
		
-- -- KB109239 (allow 0 or more spaces between words).    PRB14843 added Guernsey & Jersey		
set @UK_countries = '||UK|GB|GBR|GreatBritain|Wales|England|Scotland|NIreland|NorthernIreland|NI|UnitedKingdom|Jersey|Guernsey||' 
-- The default country is the home school country (moved up so can be used next)
select	@default_country_id = a.country_id 
from	sims.sims_school s
join	sims.school_site ss 
on		ss.home_school_id = s.school_id 
and		s.status = 's' and rank = 1
join	sims.sims_address a 
on		a.address_id = ss.address_id

-- No country: assume same as the School  
update  cont
set     country = cy.description
from    @contacts cont
join    sims.sims_country cy
on      cy.lookup_value_id = @default_country_id
where   isnull(country, '') = ''

-- 'Northern Ireland' in country table and one of the abbreviations for this is in @contacts: change to 'Northern Ireland' 
if exists(select 1 from sims.sims_country where description = 'Northern Ireland')
begin
    update  @contacts
    set     country = 'Northern Ireland'
    where   charindex('|' + replace(country, ' ','') + '|', '|NIreland|NorthernIreland|NI') > 0
end

-- Country, after ignoring spaces, is in above list  
-- and ('Northern Ireland' not in country table or @contacts country is not 'Northern Ireland')  -- PRB14834 Give same treatment to Jersey & Guernsey 
-- set to United Kingdom (no Exception message required)
update  @contacts
set     country = 'United Kingdom'
where   charindex('|' + replace(country, ' ','') + '|', @UK_countries) > 0
-- PRB14843 Added Jersey and Guernsey to list of countries not to be replaced by 'United Kingdom' (if they exist in sims.sims_country)
and not (country in ('Northern Ireland','Guernsey', 'Jersey') or not exists(select * from sims.sims_country where description = country))

-- Country not defined in sims.sims_country: log Exception and set country to 'United Kingdom'
insert	    @CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	    distinct upn, c.PreferredSurname, c.PreferredForename, c.dob, c.gender, c.person_id,  
		    'Unrecognised country (' + c.country + ') in contact''s address, saved as United Kingdom.'  
from	    @contacts c 
left join   sims.sims_country sc
on          sc.description = c.country
where       sc.description is null	
and         isnull(c.country, '') <> ''	

update	    c
set         country = 'United Kingdom'
from        @contacts  c
left join   sims.sims_country sc
on          sc.description = c.country
where       sc.description is null
and         isnull(c.country, '') <> ''	
    
-- Check whether the postcode is Valid based on the country
update	b
set		postcodeValidUK = sims.ctf_fnc_validate_UKpostcode(postcode)     
from	@contacts b
where   @UK_countries like '%|' +  replace(b.country, ' ','') + '|%'  -- i.e is empty or a UK country -- KB109239
and		ltrim(isnull(b.postcode, '')) <> ''
	
update	b
set		postcodeValidBFPO = sims.ctf_fnc_validate_BFPOpostcode(postcode)
from	@contacts b
where   @UK_countries like '%|' + replace(b.country, ' ','') + '|%'   -- PRB14843 
and		isnull(postcode, '') <> ''

-- Log and remove invalid postcodes
update	b
set		postcode = '<del>'
from	@contacts b
where	isnull(postcode, '') <> ''
and     postcodeValidBFPO = 'F'  
and     postcodeValidUK <>  'T'
and		@UK_countries not like '%|' + replace(b.country, ' ','') + '|%'   -- PRB14843 

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, c.PreferredSurname, c.PreferredForename, c.dob, c.gender, c.person_id,  
	    'Contact''s invalid address postcode not saved.'
from	@contacts c 
where   c.postcode = '<del>'
and     isnull(c. street_description, '') + isnull(c.district, '') + isnull(c.town, '') <> ''

update  @contacts
set     postcode = ''
where   postcode = '<del>'

update	b
set		posttown = null
from	@contacts b
where	len(ltrim(rtrim(isnull(posttown,'')))) > 40		

update	b
set		zipcode = null
from	@contacts b
where	len(ltrim(rtrim(isnull(zipcode,'')))) > 8
	 
update	b
set		postcode = zipcode
from	@contacts b
where	postcodeValidBFPO = 'F' AND  postcodeValidUK = 'F'
and		charindex('|' + replace(country, ' ','') + '|', @UK_countries) = 0  --kb109239
and		ltrim(isnull(zipcode, '')) <> ''	
   
-- KB113881		 	 
update  @contacts
set     PAON = sims.ctf_fnc_PAON_transform(PAON) 

-- Retrieving House Number and House Name
               
-- SAON and PAON Modified By Soawin -  The Paon field length is total 50 chars
update	 @contacts
set		house_number = ltrim(SUBSTRING(PAON,1,10) )  
where	isnull(PAON, '') <> '' 
and		sims.ctf_fnc_ValidHouseNumber(SUBSTRING(PAON,1,10)) = 1   

-- 40 chars from the 11th position in PAON are considered as House Name
update	@contacts
set		house_name = ltrim(replace(SUBSTRING(PAON,11,40), '#',' '))    
where	isnull(SUBSTRING(PAON,11,40), '') <> '' 

update	@contacts
set		apartment = ltrim(SAON)
where	isnull(SAON, '') <> ''
  and   len(ltrim(SAON)) <= 40


-- To handle multi house numbers (e.g. '11-13', which gets imported as ' 11   13')
while exists(select 1 from @contacts where house_number like '%  %') 
begin
    update	@contacts
    set		house_number = replace(house_number, '  ', ' ')
end

update	@contacts
set		house_number = replace(ltrim(rtrim(house_number)), ' ', '-')
-- KB113881 end

-- KB109239: mark empty addresses
update  @contacts 
set     empty_address = 0

update  @contacts 
set     empty_address = 1
where   ltrim(isnull(apartment, '') + isnull(flat, '') + isnull(house_name, '') + isnull(house_number, '') 
        + isnull(street_description, '') + isnull(district, '') + isnull(town, '') + isnull(postcode, '')) = ''

-- Add the non-empty Addresses into a Temporary Table
Insert @Address(
      apartment
  ,	  flat   
  ,   house_number
  ,   house_name  
  ,   street_description  
  ,   district
  ,   town
  ,   county
  ,   administrative_area
  ,   country
  ,   postcode
 ,	  property_ref_number
  ,   property_easting
  ,	  property_northing
  ,   posttown
  ,   zipcode
  ,   postcodeValidUK
  ,   postcodeValidBFPO
) 
Select  distinct 
      cts.apartment
  ,   cts.flat    
  ,   cts.house_number   
  ,   cts.house_name     
  ,   cts.street_description  
  ,   cts.district            
  ,   cts.town                
  ,   cts.county 
  ,   cts.administrative_area             
  ,   cts.country          
  ,   cts.postcode
  ,	  property_ref_number
  ,   property_easting
  ,	  property_northing
  ,   cts.posttown
  ,   cts.zipcode
  ,   cts.postcodeValidUK
  ,   cts.postcodeValidBFPO
from @contacts cts
where empty_address = 0 -- i.e. address is not empty

select	@theUK = lookup_value_id from sims.sims_country  -- KB109239 Moved up to ensure defined before used.
where	description = 'United Kingdom'

-- And set the country ID
update  @address 
set     country_id = @theUK 
where   country_id is null 
and     charindex('|' + replace(country, ' ','') + '|', @UK_countries) > 0 -- KB109239

-- Set the country ID to the lookup id.
update		@Address
set			country_id = isnull(c.lookup_value_id, @default_country_id)
from		@Address a
left join	sims.sims_country c
on			c.description = a.country
	
-- Make sure all the UK countries are 'United Kingdom'. Don't change the country description, just assign the ID.
update	@Address 
set		country_id = @theUK 
where	country_id is null 
and		charindex('|' + replace(country, ' ','') + '|', @UK_countries) > 0	-- i.e is empty or a UK country  KB109239

-- KB90688 New requirement: if CTF contains an address which is the same as the address held in the database
-- apart from the fact that the database version has no postcode and the CTF does then update the postcode.
delete	res
from	sims.sims_residence res
join	sims.sims_address a
on		res.address_id = a.address_id
join	@contacts b
on		b.person_id = res.person_id
where	b.postcode is not null
and		a.postcode is null
and		isnull(b.apartment,'') = isnull(a.apartment,'')
and		isnull(b.house_number,'') = isnull(a.house_number,'')
and		isnull(b.house_name,'') = isnull(a.house_name,'')
and		isnull(b.street_description,'') = isnull(a.street_description,'')
and		isnull(b.district,'') = isnull(a.district,'')
and		isnull(b.town,'') = isnull(a.town,'')
and		isnull(b.county,'') = isnull(a.county,'')
--and		isnull(b.country,'') = isnull(a.country,'')  -- country in address table is not used
and		getdate() between res.start_date and isnull(res.end_date, '20790606')
and		isnull(rtrim(b.postcode), '') <> ''
and		isnull(rtrim(a.postcode), '') = ''

exec sims.add_p_null_empty_address_columns

-- Address Matching: sets address_id to first matchable address in the database which matches (or null if none such)
update	@address
set		address_id = sims.add_fni_address_match(isnull(flat + ' ', '') + isnull(apartment, ''), isnull(house_name, ''), isnull(house_number, ''), 
                       isnull(street_description, ''), isnull(district, ''), isnull(town, ''), isnull(postcode, ''))
update @address
set	property_ref_number=null
where len(property_ref_number) > 12 or IsNumeric(property_ref_number) <> 1

update @address
set	property_easting=null
where len(property_easting) <> 8 or sims.add_fni_Digit_Count(property_easting) <> 7 or PATINDEX('%.%',property_easting) <> 7       --KB106416 Fix

update @address
set	property_northing=null
where len(property_northing) <> 8 or sims.add_fni_Digit_Count(property_northing) <> 7 or PATINDEX('%.%',property_northing) <> 7     --KB106416 Fix
            	
select @prevmaxaddressID = (select max(address_id) from sims.sims_address)

-- Create the Addresses which were not found.
insert sims.sims_address(
      apartment         
    , house_number      
    , house_name        
    , street_description
    , town              
    , county    
	, administrative_area
    , country_id
    , district          
    , postcode
	, property_ref_number
	, property_easting
	, property_northing
    , posttown
    , validated
    , external_id)
  select
	      left(isnull(a.flat + ' ', '') + a.apartment, 40)  -- KB113881
	    , a.house_number
     
    , a.house_name        
    , a.street_description
    , a.town              
    , a.county   
	, a.administrative_area
    , a.country_id
    , a.district          
    , a.postcode 
	, a.property_ref_number
	, a.property_easting
	, a.property_northing
    , a.posttown
    , 'F'       
    , a.external_id
  from @address a      
  where address_id is null

-- Null empty address columns. Calculate matchability
exec	sims.add_p_null_empty_address_columns

update	addr
set		matchable = sims.add_fnb_address_matchable(apartment, house_name, house_number, street_description, district, town, county, postcode)
from	sims.sims_address addr
where	address_id > @prevmaxaddressID 

-- Update the addressid into the temporary table
update	@address
set		address_id = sa.address_id
from	@address a
join	sims.sims_address sa
on		a.external_id = sa.external_id
and		a.address_id is null

-- Update the address id into the contacts table
update	@contacts
set		address_id = a.address_id
from	@contacts cts
join	@address a
on		isnull(cts.apartment,'') = isnull(a.apartment,'')
and		isnull(cts.house_number,'') = isnull(a.house_number,'')
and		isnull(cts.house_name,'') = isnull(a.house_name,'')
and		isnull(cts.street_description,'') = isnull(a.street_description,'')
and		isnull(cts.town,'') = isnull(a.town,'')
and		isnull(cts.district,'') = isnull(a.district,'')
and		isnull(cts.county,'') = isnull(a.county,'')
and		isnull(cts.administrative_area,'') =isnull(a.administrative_area,'')
--and		isnull(cts.country,'') = isnull(a.country,'')  
and		isnull(cts.postcode,'') = isnull(a.postcode,'')

 
insert into @Leavers_contacts(person_id,title,surname,forename,dob,gender)
		select sp.person_id,st.Code, sp.surname,sp.forename,sp.dob,sp.gender from sims.sims_person sp left join sims.sims_title st on sp.title_id = st.title_id
			where sp.person_id in(
					Select sr.contact_id from @leaver_Pupils lp inner join sims.stud_relation sr on lp.id = sr.student_id
					)

-- AJD: Hopefully the 8 names + 2 titles will not be over 204 chars, because that would make the message too long for this table!
insert @CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)  
select distinct cc.upn, cc.preferredSurname, cc.preferredForename, cc.dob, cc.gender, cc.person_id, 
     'Please note that ' + isnull(cc.title + ' ','') + isnull(cc.contact_forename + ' ', '') + cc.contact_surname + ' has been added as a contact for '
	 + isnull( cc.forename + ' ', '') +  cc.surname +', but '+ isnull(cc.title + ' ','') + isnull(cc.contact_forename + ' ', '') + cc.contact_surname 
	 + ' address should be checked, as pupils who previously had '+ isnull(cc.title + ' ','') + isnull(cc.contact_forename + ' ', '') 
	 + cc.contact_surname +' as a contact have now left the school and the address may therefore be out of date.'  
from @contacts cc 
inner join @Leavers_contacts lc 
  on isnull(cc.contact_forename,'') = isnull(lc.forename,'') 
  and isnull(cc.contact_surname,'') = isnull(lc.surname,'')
  and ISNULL(cc.contact_gender,'') = isnull(lc.gender,'')
  and isnull(cc.title,'') = isnull(lc.title,'')
  inner join sims.sims_residence sr on sr.person_id = lc.person_id
  where cc.address_id is null and sr.address_id is not null


  --PRB8041
declare @home_residencetype_id int
select @home_residencetype_id = lookup_value_id from sims.sims_residence_type where code = 'H'
				
  update @contacts 
  Set address_id = (select address_id from sims.sims_residence sr where sr.person_id = lc.person_id and sr.end_date is NULL and residence_type_id = @home_residencetype_id ) 
  from 
  @contacts cc inner join @Leavers_contacts lc on isnull(cc.contact_forename,'') = isnull(lc.forename,'') 
  and isnull(cc.contact_surname,'')=isnull(lc.surname,'')
  and ISNULL(cc.contact_gender,'')=isnull(lc.gender,'')
  and isnull(cc.title,'')=isnull(lc.title,'')
  where cc.address_id is null   
  

-- KB90688: Add missing postcodes to any existing addresses which match other ones but for the lack of postcode 
update	addr
set		matchable = sims.add_fnb_address_matchable(apartment, house_name, house_number, street_description, district, town, county, postcode)
from	sims.sims_address addr
where   matchable <> 1

update	a1
set		postcode = a2.postcode
from	sims.sims_address a1
join	sims.sims_address a2
on		isnull(a1.apartment, '') =	isnull(a2.apartment, '')
and		isnull(a1.house_number, '') = isnull(a2.house_number, '')
and		isnull(a1.house_name, '') = isnull(a2.house_name, '')
and		isnull(a1.street_description, '') = isnull(a2.street_description, '')
and		isnull(a1.district, '') = isnull(a2.district, '')
and		isnull(a1.town, '') = isnull(a2.town, '')
and		isnull(rtrim(a1.postcode), '') = ''
and		isnull(rtrim(a2.postcode), '') <> ''
and     a1.matchable = 1
and     a2.matchable = 1
-- KB90688

-- Validating whether a Contact_person's data already exists in the System.
-- Revised for KB109239: 
-- (a) allow phone match when no address(es) to match
-- (b) match forenames (including empty ones) or forename and fist initial e.g. J and John (but not e.g. Jo and John)
-- (c) match surnames
-- (d) Genders must not conflict (M/F or F/M) but OK if either of the genders is not given
-- (e) match address IDs, or phone numbers if no address in CTF
-- NO LONGER insist that the person is already a contact (e.g. for when child of an employee is imported)
update      cts
set         contact_id = sp.person_id         
from        @contacts cts
join        sims.sims_person sp
on          cts.contact_surname = sp.legal_surname
--PRB7340 match forename in ctf with forename in database or with initial or forename in database with ctf forename or initial
and         (isnull(cts.contact_forename, '') in (isnull(sp.forename, ''), isnull(left(sp.forename, 1), ''))
                or isnull(sp.forename, '') in (isnull(cts.contact_forename, ''), isnull(left(cts.contact_forename, 1), '')))                
and         isnull(sp.gender, '') + isnull(cts.contact_gender, '') not in ('MF','FM')
left join   sims.sims_residence sr
on          sp.person_id  = sr.person_id
left join   sims.sims_telephone tel
on          sp.person_id = tel.person_id 
left join   sims.sims_address sa
on          sa.address_id = sr.address_id
left join   @phones ph
on          ph.contact_surname  = cts.contact_surname              
and         ph.contact_forename = cts.contact_forename
and         ph.contact_gender   = cts.contact_gender              
and         ph.contact_relationship = cts.contact_relationship          
where       sr.address_id = cts.address_id
or          sims.add_fnc_one_line_address(sr.address_id, 0) = sims.add_fnc_one_line_address(cts.address_id, 0)
--          -- Allow match on phone numbers if CTF or database has no address   
or          ((cts.Empty_address = 1 and(sr.address_id is null or sims.add_fnc_one_line_address(sr.address_id, 0) = '')) 
              and sims.ctf_fnb_phone_match(isnull(tel.number, 'X'), isnull(ph.phone_no, 'Y')) = 1) -- in any case they need 6+ digits before they can match

-- PRB14843 Another way to determine we have this contact in SIMS already: same name criteria as above, and having the same relationship to the same student
-- (in which case we do not need to worry if they have the same address or phone
update  cts
set     contact_id = sp.person_id         
from    @contacts cts
join    sims.sims_person sp
on      cts.contact_surname = sp.legal_surname
and     (isnull(cts.contact_forename, '') in (isnull(sp.forename, ''), isnull(left(sp.forename, 1), ''))
                or isnull(sp.forename, '') in (isnull(cts.contact_forename, ''), isnull(left(cts.contact_forename, 1), '')))                
and     isnull(sp.gender, '') + isnull(cts.contact_gender, '') not in ('MF','FM')
join    sims.stud_relation sr
on		sr.contact_id = sp.person_id              
and		sr.student_id =  cts.person_id
join    sims.stud_relation_type rt
on		rt.relation_type_id = sr.relation_type_id
and     rt.code = cts.contact_relationship    
where   cts.contact_id is null
and		sp.person_id is not null
  
--PRB14843 Likewise for applicant instead of student
update  cts
set     contact_id = sp.person_id         
from    @contacts cts
join    sims.sims_person sp
on      cts.contact_surname = sp.legal_surname
and     (isnull(cts.contact_forename, '') in (isnull(sp.forename, ''), isnull(left(sp.forename, 1), ''))
                or isnull(sp.forename, '') in (isnull(cts.contact_forename, ''), isnull(left(cts.contact_forename, 1), '')))                
and     isnull(sp.gender, '') + isnull(cts.contact_gender, '') not in ('MF','FM')
join    sims.adm_application_relation ar
on		ar.contact_id = sp.person_id 
join    sims.adm_application a
on		a.person_id = cts.person_id   
and		ar.application_id = a.application_id           
join    sims.stud_relation_type rt
on		rt.relation_type_id = ar.relation_type_id
and     rt.code = cts.contact_relationship    
where   cts.contact_id is null
and		sp.person_id is not null

-- Inserting the data into the sims.sims_person table
-- and storing back the person_id in the temporary Table for further inserting the
-- relation  ( link )  records into the Table
insert into @Person(
  title           
, contact_gender  
, contact_surname 
, contact_midname 
, contact_forename
, address_id
)
Select distinct
    isnull(cts.title,'')
  , cts.contact_gender
  , cts.contact_surname
  , cts.contact_midname
  , cts.contact_forename
  , cts.address_id
from @contacts cts
where cts.contact_id is null

--Update external ids into @person table
update @person 
set external_id = newid()

--Raise error for unrecognised title. Dont insert into sims.sims_title table
insert	    @CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	    upn, PreferredSurname, PreferredForename, dob, gender, person_id,
			'The title ''' + isnull(title,'') + ''' was not imported for the contact ''' + isnull(contact_forename + ' ', '') + contact_surname + ''' as it is unrecognised'
from        @contacts cnt
left join   sims.sims_title st
on          cnt.title  = st.Code
where       st.Code is null

-- Add contacts to sims_person 
select @contact_aggregate_role = role from sims.sims_role_text where description = 'Contact'

Insert into sims.sims_person (
    title_id
  , gender
  , surname
  , legal_surname
  , midname
  , forename
  , aggregate_role
  , last_updated
  , External_ID
)
Select 
    st.title_id
  , Per.contact_gender
  , Per.contact_surname
  , Per.contact_surname
  , Per.contact_midname
  , Per.contact_forename
  , @contact_aggregate_role
  , getdate()
  , Per.external_id
from @Person Per
left join sims.sims_title st
on Per.title  = st.Code

-- Updating the Person details in the sims_person based on the External_id
-- Update the External_id for the new students only
/*Join on Title,Surname,Forename,Gender,Midname and Address_id is to establish link between @contacts and @Person table*/

update  @contacts
set     contact_id = sp.person_id
from    @contacts cts
join    @person per
on      isnull(cts.title,'') = isnull(per.title,'')
and     cts.contact_gender = per.contact_gender
and     cts.contact_surname = per.contact_surname
and     cts.contact_midname = per.contact_midname
and     cts.contact_forename = per.contact_forename
and     isnull(cts.address_id, 0) = isnull(per.address_id, 0)
join    sims.sims_person sp
on      sp.external_id = per.external_id

-- 24/04/2017 What about ones matched by 'same relationship to same applicant/student' with no address?  
/*Update Person Id in Phones table*/
--PRB7340 match student UPN as in some cases other condition values will be same and phone number of one contact is assigned to others
Update  p
set     contact_id = cts.contact_id
from    @Phones p
join    @contacts cts 
on      isnull(cts.title,'') = isnull(p.title,'')
and     cts.contact_surname  = p.contact_surname
and     cts.contact_forename = p.contact_forename
and     cts.contact_midname  = p.contact_midname
and     cts.contact_gender   = p.contact_gender
and     isnull(cts.contact_relationship,'') = isnull(p.contact_relationship,'')
and     isnull(cts.contact_parent_responsibility,'') = isnull(p.contact_parent_responsibility,'')
and     cts.upn = p.upn  

--Deleting all unmatched contacts from Phones table
Delete from @Phones where contact_id is null

-- 24/04/2017 Terminate any current home residence record for those we are about to add
update	sr
set		end_date = dateadd(mi, -1, @start_date)
from	sims.sims_residence sr
join	@Contacts cts  
on      sr.person_id = cts.contact_id  
where   @start_date between sr.[start_date] and isnull(sr.end_date, '20790606')
and     isnull(cts.address_id, 0) > 0  
and     sr.[type] = 'H'

-- Insert a link between the Contact and the Address in the Database which does not exists  
insert sims.sims_residence (address_id, person_id, type, start_date, residence_type_id)  
select distinct address_id, contact_id, 'H', @start_date, srt.lookup_value_id  
from @Contacts  cts  
join sims.sims_residence_type srt  
on  srt.code = 'H'  
and not exists(select 1 from sims.sims_residence sr   
              where sr.person_id = cts.contact_id and  
                    sr.address_id = cts.address_id and  
					@start_date between sr.[start_date] and isnull(sr.end_date, '20790606'))
and isnull(cts.address_id ,0) > 0   -- Check for a address tag is present. 

-- Inserting the person as a Contact in the Database
insert  sims.stud_contact (person_id, ballot, translator)
select  distinct cts.contact_id, 'F', 'F'
from    @contacts cts
where	not exists(select 1 from sims.stud_contact sc where sc.person_id = cts.contact_id)
 	
if @region in ('ENG', 'WALES') 
begin
    -- Map Contact relationship code for STP and FOS
	update	ct 
	set		contact_relationship = sims.fn_GetContactMappingCode(ct.contact_relationship, ct.contact_id)
	from	@contacts ct
	where	contact_relationship in('STP' ,'FOS')
end
else if @region = 'NI'  
begin
    -- If NI then convert PAF/PAM to PAR
    update  ct
    set     contact_relationship = 'PAR'
    from    @contacts ct
    where   ct.contact_relationship in ('PAF','PAM')
end

 -- Insert error if the relation does not exist as part of category
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, preferredSurname, preferredForename, dob, gender, person_id
            	, 'Relationship ''' + ct.contact_relationship + ''' is unrecognised for '  + ct.contact_surname
		+ ' ' + ct.contact_forename + '. Relation ''OTH'' will be used instead'
from	@contacts ct
where not exists (select 1 from sims.stud_relation_type_category
                  where code = ct.contact_relationship)

-- Replace the unrecognised relationship with code 'OTH'
update  ct
set     contact_relationship = 'OTH'
from    @contacts ct
where not exists (select 1 from sims.stud_relation_type_category
                  where code = ct.contact_relationship)


-- We need to link the list of imported contacts (later in this procedure) to a given ctf import.  
-- To do this we need to link it to the record in the ctf_import table. Unfortunately that table  
-- is written after this point so we need to store a temporary number here and then update it later.  
-- This will be fine unless two CTF imports are being run on two different machines in the  
-- school at exactly the same time. I'm not going to try and code a fancy   
-- multi-concurrency version of this because (a) this situation is extremely unlikely,  
-- (b) we don't generally attempt to deal with concurrency issues in SIMS anyway  
-- and (c) this would be a big piece of work to do properly and I don't feel the risk  
-- is nearly big enough to justify the cost.  
  
set @ctf_import_id = -9999  
  
-- Store details of the contacts for students which are being added in this import. We can use this later to  
-- produce a report for users  
  
insert into sims.ctf_imported_contact_data  
				(import_id, contact_id, student_or_applicant, student_id, applicant_id)  
	select distinct  
			@ctf_import_id  
			,contact_id  = cts.contact_id  
			,'S'							-- student  
			,person_id  = cts.person_id  
			,null  
	from	@contacts  cts  
	join    sims.stud_relation_type srt	on	srt.code = cts.contact_relationship  
			and not exists(	select 1   
							from	sims.stud_relation sr   
							where	sr.student_id = cts.person_id   
							and		sr.contact_id = cts.contact_id)  
	where	cts.is_applicant = 'F'  


-- Insert relation between Student and contact.
Insert into sims.stud_relation (
	  relation_type_id
	, student_id
	, contact_id
	, parental_responsibility
	, priority
	, legal_order
	, correspondence
	, pupil_report
	, copy_bills
)
Select distinct
	[relation_type_id]	= srt.relation_type_id
	, [person_id]		= cts.person_id
	, [contact_id]		= cts.contact_id
	, [responsibility]	= upper(cts.contact_parent_responsibility)
	, [priority	]	    = cts.priority
	, [legal_order]		= case isnull(cts.court_order, '') when 'Y' then 'T' else 'F' end
	, [correspondence]	= 'F'
	, [pupil_report]	= 'F'
	, [copy_bills]		= 'F' -- KB115474
from  @contacts  cts
join    sims.stud_relation_type srt 
on      srt.code = cts.contact_relationship
and not exists(select 1 
		from sims.stud_relation sr 
		where sr.student_id = cts.person_id 
		and sr.contact_id = cts.contact_id)
where cts.is_applicant = 'F'


-- Store details of the contacts for applicants which are being added in this import. We can use this later to  
-- produce a report for users  
  
insert into sims.ctf_imported_contact_data  
				(import_id, contact_id, student_or_applicant, student_id, applicant_id)  
	select distinct  
			@ctf_import_id  
			,contact_id  = cts.contact_id  
			,'A'    -- Applicant  
			,null  
			,person_id  = ra.person_id  
	from	@contacts  cts  
	join	sims.stud_relation_type srt	on	srt.code = cts.contact_relationship  
	join	sims.adm_application ra		on	cts.person_id =  ra.person_id  
			and not exists(	select  1   
							from    sims.adm_application_relation ral  
							join    sims.adm_application app	on	app.application_id = ral.application_id  
							where   ral.contact_id = cts.contact_id
							and     app.person_id = ra.person_id)  
	where	cts.is_applicant = 'T'  


-- Insert relation between Applicant and Contact.
Insert into sims.adm_application_relation(
	  relation_type_id
	, application_id
	, contact_id
	, parental_responsibility
	, priority
	, legal_order
	, correspondence
	, pupil_report
	, copy_bills
    , email_bills)
Select distinct
	  [relation_type_id]	= srt.relation_type_id
	, [application_id]	= ra.application_id
	, [contact_id]		= cts.contact_id
	, [responsibility]	= case upper(cts.contact_parent_responsibility) when 'T' then 1 else 0 end
	, [priority]		= cts.priority
	, [legal_order]		= case isnull(cts.court_order, '') when 'Y' then 1 else 0 end
	, [correspondence]	= 0
	, [pupil_report]	= 0
	, [copy_bills]		= 0 -- KB115474
	, [email_bills]		= 0

from    @contacts  cts
join    sims.stud_relation_type srt 
on      srt.code = cts.contact_relationship
join    sims.adm_application ra 
on      cts.person_id =  ra.person_id
and not exists( select  1 
                from    sims.adm_application_relation ral
                join    sims.adm_application app 
                on      app.application_id = ral.application_id
		        where   ral.contact_id = cts.contact_id
		        and     app.person_id = ra.person_id)
where cts.is_applicant = 'T'


-- Insert the contact's telephone other than fax related data into the System
Insert  sims.sims_telephone ( person_id, device, location, number, main)
select  distinct contact_id, 'T', p.phone_type, p.phone_no, 'F'
from    @Phones p
where   p.phone_type <> 'F' and p.phone_type <> 'O' 
and     not exists(select 1
		            from sims.sims_telephone st
		            where st.person_id = p.contact_id
		            and st.number = p.phone_no
		            and st.location = p.phone_type
                    and st.device <> 'F'
                    )		

-- Insert contact's fax telephone data into the system - Location is 'H' always and Main is 'F'
Insert sims.sims_telephone( person_id, device, location, number, main)
select distinct contact_id, 'F', 'H', p.phone_no, 'F'
from    @Phones p
where   p.phone_type = 'F' and p.phone_type <> 'O' 
and not exists( select 1
		        from sims.sims_telephone st
		        where st.person_id = p.contact_id
		        and st.number = p.phone_no
                and st.device = 'F'
                )


/************************************** CTF 9.0 changes ******************************************/

-- Insert/Update contact's email addresses

-- insert a new email record if the preson does not already have this email_address
insert  sims.sims_email(person_id, location, main, email_address)
select  distinct c.contact_id, 'H', 'F', c.email
from    @contacts c
where   sims.ctf_fnc_validate_EMailAddress(c.email) = 'T' -- empty ones are not valid
and not exists( select  1
                from    sims.sims_email e 
                where   e.person_id = c.contact_id 
                and     e.email_address = c.email )  

/************************************** CTF 9.0 changes end here ******************************************/

-- AJD 29/05/2011  Name contacts with missing address data. If no address just state this instead of reporting each missing part.   
-- Add exceptions 
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with no address: ' + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname     
from	@contacts b 
where	empty_address = 1

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'The UPRN for contact: '+ isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + ' wasn''t imported as the format is invalid'
from	@contacts b 
where	len(property_ref_number) >= 1 
and     empty_address = 0
and     (len(property_ref_number) > 12 or IsNumeric(property_ref_number) <> 1)

--Delete invalid UPRN records, so that same not get imported
delete @contacts
where	len(property_ref_number) >= 1 
and     empty_address = 0
and     (len(property_ref_number) > 12 or IsNumeric(property_ref_number) <> 1)

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with invalid Easting: ' + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname
from	@contacts b 
where	len(property_easting) > 1 and ( len(property_easting) <> 8 or sims.add_fni_Digit_Count(property_easting) <> 7 or PATINDEX('%.%',property_easting) <> 7 ) --KB106416 Fix
and     empty_address = 0

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with invalid Northing: '  + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname
from	@contacts b 
where	len(property_northing) > 1
and		( len(property_northing) <> 8 or sims.add_fni_Digit_Count(property_northing) <> 7 or PATINDEX('%.%',property_northing) <> 7 ) --KB106416 Fix
and     empty_address = 0

set @MIV = '. Please check imported address.'

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with missing or invalid <SAON>: ' + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + @MIV
from	@contacts b 
where	sims.ctf_fnc_ValidHouseNumber(SUBSTRING(SAON,1,10)) = 0  			-- modified ajd 11/07/2009	
and     ((ltrim(isnull(SUBSTRING(SAON,1,10),'')) <> '') or len(ltrim(SAON)) > 40)
and     b.empty_address = 0
  
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with missing or invalid <PAON>: ' + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + @MIV
from	@contacts b 
where	ltrim(isnull(PAON,'')) = '' 
and		postcodeValidBFPO = 'F'
and     b.empty_address = 0       

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct  upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with missing <Street>: '  + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + @MIV
from	@contacts b 
where	ltrim(isnull(street_description,'')) = '' 
and		postcodeValidBFPO = 'F'
and     b.empty_address = 0 	 

insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with missing <Locality>, <Town> and <AdministrativeArea>: '  + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + @MIV
from	@contacts b  
where	ltrim(isnull(district,'') + isnull(town,'') + isnull(county,'') + isnull(administrative_area,'')) = ''
and		postcodeValidBFPO = 'F'
and     b.empty_address = 0 
     
-- Add exception for invalid postcode
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, b.PreferredSurname, b.PreferredForename, dob, gender, person_id,
		'Contact with missing Postcode: '  + isnull(title + ' ','') + isnull(contact_forename + ' ', '') + contact_surname + @MIV
from	@contacts b 
where	postcodeValidUK = 'F' 
and		postcodeValidBFPO = 'F'
and		charindex('|' + replace(country, ' ','') + '|', @UK_countries) > 0	-- i.e is  a UK country  KB109239
and		country <> ''
and     b.empty_address = 0 	 

-- 49352
insert	@CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
select	distinct upn, p.surname, p.forename, dob, gender, person_id,
		'Telephone Type ''O'' is not valid for CTF import. Telephone number '  + phone_no + ' for Contact ' + isnull(p.contact_surname, surname) + ' ' + isnull(p.contact_forename, forename) + ' has not been imported.' 
from	@Phones p  
where	p.phone_type = 'O'


-- CTF 9.0 changes
-- Add exception for invalid e-mail addresses

	insert  @CTF_Errors(upn, surname, forename, dob, gender, person_id, errormsg)
	select  upn, preferredSurname, preferredForename, dob, gender, person_id,
            'Pupil contact has one or more invalid e-mail address.'
	from    @contacts b 
    where ( isnull(b.email,'') <> '') 
    and     (sims.ctf_fnc_validate_EMailAddress(b.email) = 'F')

-- KB110481. update the Student or Application salutation & parent_address if required 
-- Calculate number of parents who reside with the applicant or student
update  @CTF_PupilData
set     num_parents = sims.ctf_fni_number_of_co_resident_parents(is_applicant, person_ID, @region, @start_date) 

update  ss  
set     salutation = sims.sta_fnc_getStudent_Salutation_Information (aa.person_id, @start_date)   
from    sims.adm_application aa  
join    @CTF_PupilData cpd   
on      aa.person_id = cpd.person_id 
join    sims.adm_application_additional ss
on      ss.application_id = aa.application_id
where   cpd.is_Applicant = 'T'
and     aa.application_id = (select max(application_id) from sims.adm_application where person_id = cpd.person_id) 
and     (isnull(ltrim(ss.salutation), '') = '' 
         or cpd.recalc_Salutation = 1 
         or (cpd.num_parents = 2 and charindex(' and ', salutation) = 0 and charindex('&', salutation) = 0)
        )
       
update  ss  
set     salutation = sims.sta_fnc_getStudent_Salutation_Information (ss.person_id, @start_date)   
from    sims.stud_student ss  
join    @CTF_PupilData cpd   
on      ss.person_id = cpd.person_id 
where   cpd.is_Applicant = 'F'
and     (isnull(ltrim(ss.salutation), '') = '' 
         or cpd.recalc_Salutation = 1 
         or (cpd.num_parents = 2 and charindex(' and ', salutation) = 0 and charindex('&', salutation) = 0)
        )

update  ss  
set     parent_address = sims.sta_fnc_getStudent_Addressee_Information (aa.person_id, @start_date, @parental_addressee_format_type)   
from    sims.adm_application aa  
join    @CTF_PupilData cpd   
on      aa.person_id = cpd.person_id 
join    sims.adm_application_additional ss
on      ss.application_id = aa.application_id
where   cpd.is_Applicant = 'T'
and     aa.application_id = (select max(application_id) from sims.adm_application where person_id = cpd.person_id) 
and     (isnull(ltrim(parent_address), '') = '' 
         or cpd.recalc_parent_address = 1 
         or (cpd.num_parents = 2 and charindex(' and ', parent_address) = 0 and charindex('&', parent_address) = 0)
         )

       
update  ss  
set     parent_address = sims.sta_fnc_getStudent_Addressee_Information (ss.person_id, @start_date, @parental_addressee_format_type)    
from    sims.stud_student ss  
join    @CTF_PupilData cpd   
on      ss.person_id = cpd.person_id 
where   cpd.is_Applicant = 'F'
and     (isnull(ltrim(parent_address), '') = ''
         or cpd.recalc_parent_address = 1 
         or (cpd.num_parents = 2 and charindex(' and ', parent_address) = 0 and charindex('&', parent_address) = 0)
        )

--  Two Current Home Residence records for the same person with different start dates: terminate the earlier one:
declare @now smalldatetime, @cont bit, @residence_id1 int, @residence_id2 int
select @cont = 1, @now = getdate()
while @cont = 1
begin
	set		@residence_id1 = null
	select	@residence_id1 = r1.residence_id,  @residence_id2 = r2.residence_id, @start_date = r2.[start_date]
	from	sims.sims_residence r1
	join	sims.sims_residence r2
	on		r1.person_id = r2.person_id
	and		@now between r1.[start_date] and isnull(r1.end_DATE, '20790606')
	and		@now between r2.[start_date] and isnull(r2.end_DATE, '20790606')
	and		r1.[type] = 'H'
	and		r2.[type] = 'H' 
	and     r1.[start_date]  < r2.[start_date]

	if @residence_id1 is null set @cont = 0 else 
	begin
		update	sims.sims_residence 
		set		end_date = dateadd(mi, -1, @start_date)
		where   residence_id = @residence_id2
	end
end

--- result set
 
select upn, surname, forename, dob, gender, person_id, errormsg
from @CTF_Errors

return 0
go

------------------------------------------------------------------------------------------------------------------
--- Grant Execute to Simsuser and provide skeleton test harness
--grant execute on sims.ctf_pix_CTFImport_SaveStudentContact to simsuser
/*
--Case 1
declare @on_roll varchar(1)
select @on_roll = 'T'
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H82020018012" Surname="Shah" Forename="Ritu" DOB="1993-10-12" Gender="F" PersonId="4343" MatchFound="F"/>
</data>
'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H82020018011" Surname="Mishra" Forename="Anmol" DOB="1994-06-26" Gender="M"/>
  <Contacts>
   <ContactDetails>
    <Contact Order="3" Title="Mr" Surname="Abryaham" Forename="Susayn" MiddleNames="" Gender="F" RelationShip="PRB" Responsibility="F"/>
    <Address Apartment = "HAMPSHIRE"  HouseName = "HOUSE"  HouseNo= "18" StreetDes = "Nant-y-caws"
            District = "Brewood"  Town = "Wilverton" County = "Rapshire"  Country = "" PostCode = "SI109AN"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="751699"/>
       <Phone PhoneType="M" PhoneNo="851399"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

-- Case 2
declare @PupilsXML  varchar(8000)
declare @on_roll varchar(1)
select @on_roll = 'T'
select @PupilsXML = 
'
<data>
 <row UPN="H820200198012" Surname="Shah" Forename="Ritu" DOB="1993-10-12" Gender="F" PersonId="4343" MatchFound="F"/>
</data>
'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198012" Surname="Shah" Forename="Ritu" DOB="1993-10-12" Gender="F"/>
  <Contacts>
   <ContactDetails>
    <Contact Order="1" Title="MArs" Surname="Arya" Forename="Aniket" MiddleNames="" Gender="M" RelationShip="CHM" Responsibility="F"/>
    <Address Apartment = "House"  HouseName = ""  HouseNo= "35" StreetDes = "GLADYS"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="342353"/>
       <Phone PhoneType="M" PhoneNo="342342"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="2" Surname="Patel" Forename="Rupali" MiddleNames="Ashok" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address Apartment = "Lower Bay"  HouseName = "FLAT"  HouseNo= "8" StreetDes = "Smithfield Rd" Town = "East Town" County = "Eastshire" Country = "SI1 1BB"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

-- Case 3
declare @on_roll varchar(1)
select @on_roll = 'T'
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H820200198012" Surname="Shah" Forename="Ritu" DOB="1993-10-12" Gender="F" PersonId="4343" MatchFound="F"/>
</data>
'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198012" Surname="Shah" Forename="Ritu" DOB="1993-10-12" Gender="F"/>
  <Contacts>
   <ContactDetails>
    <Contact Order="1" Title="Mr" Surname="Arya" Forename="Aniket" MiddleNames="" Gender="M" RelationShip="CHM" Responsibility="F"/>
    <Address Apartment = "House"  HouseName = ""  HouseNo= "35" StreetDes = "GLADYS"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="342353"/>
       <Phone PhoneType="M" PhoneNo="342342"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="2" Surname="Patel" Forename="Rupali" MiddleNames="Ashok" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address Apartment = "Lower Bay"  HouseName = "FLAT"  HouseNo= "8" StreetDes = "Smithfield Rd" Town = "East Town" County = "Eastshire"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="3" Surname="Patel" Forename="Rupali" MiddleNames="Ashok" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address Apartment = "Oyster Bay"  HouseName = "FLAT"  HouseNo= "10" StreetDes = "Omni Rd" Town = "East Town" County = "Eastshire" Country = "UK"/>
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

--Case 4 -- Two contacts having different address
declare @on_roll varchar(1)
select @on_roll = 'T'
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F" PersonId="4345" MatchFound="F"/>
</data>
'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F"/>
  <Contacts>
  <ContactDetails>
    <Contact Order="1" Surname="Rao" Forename="Suman" MiddleNames="Raghu" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "12" StreetDes = "Kimbolton Road" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 9YB" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="2" Surname="Mehra" Forename="Rahul" Gender="M" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "14" HouseName = "The Avenue" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 99B" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="4543534"/>
       <Phone PhoneType="M" PhoneNo="4393578700"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 


--Case 5  Two Contacts having the same address
declare @on_roll varchar(1)
select @on_roll = 'T'
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F" PersonId="4345" MatchFound="F"/>
</data>
'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F"/>
  <Contacts>
  <ContactDetails>
    <Contact Order="1" Surname="Rao" Forename="Suman" MiddleNames="Raghu" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "12" StreetDes = "Kimbolton Road" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 9YB" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="2" Surname="Mehra" Forename="Rahul" Gender="M" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "14" HouseName = "The Avenue" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 99B" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="4543534"/>
       <Phone PhoneType="M" PhoneNo="4393578700"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="3" Surname="Yadav" Forename="Santosh" Gender="M" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "14" HouseName = "The Avenue" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 99B" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="4543534"/>
       <Phone PhoneType="M" PhoneNo="4393578700"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

--Case 6  Contacts details are same but address is different
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F" PersonId="4345" MatchFound="F"/>
</data>
'
declare @on_roll varchar(1)
select @on_roll = 'T'
declare @StudentContactsXML  varchar(8000)
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F"/>
  <Contacts>
  <ContactDetails>
    <Contact Order="1" Surname="Rao" Forename="Suman" MiddleNames="Raghu" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "12" StreetDes = "Kimbolton Road" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 9YB" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
   <ContactDetails>
    <Contact Order="2" Surname="Rao" Forename="Suman" MiddleNames="Raghu" Gender="F" RelationShip="REL" Responsibility="F"/>
    <Address HouseNo= "17" HouseName = "The Uphill" Town = "Bedford" County = "BedfordShire" PostCode = "SA7 19B" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="4543534"/>
       <Phone PhoneType="M" PhoneNo="4393578700"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 



--Case 7
declare @StudentContactsXML  varchar(8000)
declare @PupilsXML  varchar(8000)
declare @on_roll varchar(1)
select @on_roll = 'T'
select @PupilsXML = 
'
<data>
 <row UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F" PersonId="4345" MatchFound="F"/>
</data>
'
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F"/>
  <Contacts>
  <ContactDetails>
    <Contact Order="3" Surname="Spencer" Forename="Harrison" Gender="M" RelationShip="CHM" Responsibility="F"/>
    <Address HouseNo= "12" StreetDes = "Shakesphere Road" Town = "Bedford" County = "BedfordShire" PostCode = "SA2 9YB" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

--Case 8

-- Deliberate error: Missing Forename on Contact

declare @StudentContactsXML  varchar(8000)
declare @PupilsXML  varchar(8000)
select @PupilsXML = 
'
<data>
 <row UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F" PersonId="4345" MatchFound="F"/>
</data>
'
select @StudentContactsXML = 
'<Root>
 <StudentContact>
  <MatchTag UPN="H820200198014" Surname="Gupta" Forename="Malika" DOB="1992-11-13" Gender="F"/>
  <Contacts>
  <ContactDetails>
    <Contact Order="3" Surname="Spencer" Gender="M" RelationShip="CHM" Responsibility="F"/>
    <Address HouseNo= "12" StreetDes = "Shakesphere Road" Town = "Bedford" County = "BedfordShire" PostCode = "SA2 9YB" />
    <Phones>
       <Phone PhoneType="H" PhoneNo="436446"/>
       <Phone PhoneType="M" PhoneNo="439853200"/>
    </Phones>
   </ContactDetails>
  </Contacts>
 </StudentContact>
</Root>'
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML, @PupilsXML, 'F' 

-- Unit Test
-- Case 0412-850193
-- Lisa Passfield
-- 9th December 2004

exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><MatchTag UPN="U851270095062" Surname="Abbott" Forename="Jack" DOB="1991-01-25" Gender="M" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><StudentContact><MatchTag UPN="U851270095062" Surname="Abbott" Forename="Jack" DOB="1991-01-25" Gender="M" FormerUPN="" FormerSurname=""></MatchTag><Contacts><ContactDetails><Contact Order="2" Title="Mr" Surname="Abbott" Forename="Ken" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" HouseName="" HouseNo="102" StreetDes="Folkestone Road" District="" Town="Portsmouth" County="" Country="" PostCode="PO3 6LR"></Address><Phone PhoneType="M" PhoneNo="07786 130232"></Phone><Phone PhoneType="W" PhoneNo="92 753237"></Phone><Phone PhoneType="H" PhoneNo="023 92671966"></Phone></ContactDetails><ContactDetails><Contact Order="1" Title="Ms" Surname="Doubleday" Forename="Karel" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" HouseName="" HouseNo="102" StreetDes="Folkestone Road" District="" Town="Portsmouth" County="" Country="" PostCode="PO3 6LR"></Address><Phone PhoneType="M" PhoneNo="07786 000287"></Phone><Phone PhoneType="W" PhoneNo="92346565"></Phone><Phone PhoneType="H" PhoneNo="023 92671966"></Phone></ContactDetails></Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data> <row UPN=''U851270095062'' Surname=''Abbott'' Forename=''Jack'' DOB=''1991-01-25T00:00:00'' Gender=''M'' PersonId=''2797'' MatchFound=''T'' /></data>', @on_roll = 'T'

-- Unit Test for CR25630
-- Lisa P. 16/12/2004
-- Don't match on country because blank ones are updated with a default.  This is then matched with existing
-- address which may not have a country added, then the match will fail and a new address added.

exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><MatchTag UPN="W820432100004" Surname="Arthur" Forename="Edwina" DOB="1989-07-06" Gender="F" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><StudentContact><MatchTag UPN="W820432100004" Surname="Arthur" Forename="Edwina" DOB="1989-07-06" Gender="F" FormerUPN="" FormerSurname=""></MatchTag><Contacts><ContactDetails><Contact Order="2" Title="Mrs" Surname="Arthur" Forename="K" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" HouseName="" HouseNo="49" StreetDes="Pickhill" District="Bo''ness" Town="East Town" County="Eastshire" Country="" PostCode=""></Address><Phone PhoneType="H" PhoneNo="01234 658951"></Phone><Phone PhoneType="W" PhoneNo="01234 951236"></Phone></ContactDetails><ContactDetails><Contact Order="1" Title="Mr" Surname="Arthur" Forename="Arthur" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" HouseName="" HouseNo="49" StreetDes="Pickhill" District="Bo''ness" Town="East Town" County="Eastshire" Country="" PostCode=""></Address><Phone PhoneType="H" PhoneNo="01234 658951"></Phone><Phone PhoneType="W" PhoneNo="01234 851236"></Phone></ContactDetails></Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data> <row UPN=''W820432100004'' Surname=''Arthur'' Forename=''Edwina'' DOB=''1989-07-06T00:00:00'' Gender=''F'' PersonId=''1932'' MatchFound=''T'' /></data>', @on_roll = 'T'

-- Results
-- Before: Will add duplicate address and contact because even though they are identical in the xml and the
-- database, adding the default country, then using that to compare with existing data that may not have country
-- will fail the match

Looking in the front end the student has duplicate contacts, two with address and no country, two with address and country as UK
Delete duplicate contacts' addresses, then delete the relationships from students.
Delete the duplicate address from sims.sims_address, change code to remove country from match criteria, then run again

-- After: No duplicate address or contact is added because the match is found.
-- No duplicate contacts or address added
select address_id from sims.sims_address where house_number='49' and street_description='Pickhill'

address_id  
----------- 
888

-- Only one address found with and old id number so it's old.

-- Unit Test for CR23750
-- By Lisa Passfield
-- 14th January 2005

-- Incorrectly splitting PAON into house number and house name

exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><MatchTag UPN="X820432104001" Surname="passfield" Forename="lisa" DOB="1990-09-29" Gender="F" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1
exec sims.ctf_pix_CTFImport_SaveStudentContact
 @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
 <StudentContact><MatchTag UPN="X820432104001" Surname="passfield" Forename="lisa" DOB="1990-09-29" Gender="F" FormerUPN="" FormerSurname=""></MatchTag>
 <Contacts><ContactDetails><Contact Order="1" Title="Mrs" Surname="Mullen" Forename="Candice" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
  <Address
   Apartment=""
   PAON="37b, The Mews"
   StreetDes="Trefaenor"
   District="Rotherham"
   Town="Abergirth"
   County="Hartshire"
   Country=""
   PostCode="">
  </Address>
  <Phone PhoneType="H" PhoneNo="211474"></Phone><Phone PhoneType="W" PhoneNo="405992"></Phone></ContactDetails>
 </Contacts></StudentContact></Root>',
 @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?>
 <data><row UPN=''X820432104001'' Surname=''passfield'' Forename=''lisa'' DOB=''1990-09-29T00:00:00'' Gender=''F'' PersonId=''2794'' MatchFound=''T'' /></data>',
 @on_roll = 'T'

select address_id from sims.sims_address where house_number = '37b' and house_name = 'The Mews'

address_id  
----------- 
1565

select res.address_id,
 per.person_id,
 substring(per.legal_surname, 1, 10) as surname,
 substring(per.forename, 1, 10) as forename,
 substring(addr.house_number, 1, 10) as house_number,
 substring(addr.house_name, 1, 10) as house_name,
 substring(addr.street_description, 1, 10) as street,
 addr.postcode
from sims.sims_residence res inner join sims.sims_person per on per.person_id=res.person_id
 inner join sims.sims_address addr on res.address_id = addr.address_id
where res.address_id=1565

-- results

address_id  person_id   surname    forename   house_number house_name street     postcode 
----------- ----------- ---------- ---------- ------------ ---------- ---------- -------- 
1565        2795        Mullen     Candice    37b          The Mews   Trefaenor  
1565        2794        passfield  lisa       37b          The Mews   Trefaenor  

-- The student and contact have been assigned the same address with the number and name in the correct fields.
-- More comprehensive unit tests have already been done as part of the sims.ctf_fnc_ValidHouseNumber function


-- Unit Test for CR26806
-- By Lisa Passfield
-- 20th January 2005
-- Post Code not matching if there's a space in it in the XML and not in the database.  CTF Export puts the space
-- in so the same address won't be recognised when imported back in.

-- Front end also puts in the space, so it they must have come from dbase.

-- Export Ben Abbot who had a valid post code and contacts at the same address

-- Before fix, Import Ben Abbot

exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><StudentContact><MatchTag UPN="U820432190122" Surname="Abbot" Forename="Ben" DOB="1986-01-17" Gender="M" FormerUPN="" FormerSurname=""></MatchTag><Contacts><ContactDetails><Contact Order="2" Title="Mr" Surname="Abbot" Forename="Francis" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" PAON="22" StreetDes="Brick Hill Drive" District="Rainham" Town="EAST TOWN" County="Eastshire" Country="" PostCode="MK41 7PZ"></Address><Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0398 987234"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone></ContactDetails><ContactDetails><Contact Order="1" Title="Mrs" Surname="Abbot" Forename="R" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" PAON="22" StreetDes="Brick Hill Drive" District="Rainham" Town="EAST TOWN" County="Eastshire" Country="" PostCode="MK41 7PZ"></Address><Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0378 984326"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone></ContactDetails></Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data> <row UPN=''U820432190122'' Surname=''Abbot'' Forename=''Ben'' DOB=''1986-01-17T00:00:00'' Gender=''M'' PersonId=''1740'' MatchFound=''T'' /></data>', @on_roll = 'T'

-- A new contact address is added with a space in the post code

select address_id, house_number, postcode from sims.sims_address where street_description='Brick Hill Drive'

-- Address is imported again with the space in the post code

address_id  house_number                             postcode 
----------- ---------------------------------------- -------- 
1572        22                                       MK41 7PZ
1345        22                                       MK417PZ

-- And the new address means the contact also failed to match and has also been duplicated

select per.person_id, addr.address_id, res.residence_id, per.surname as contact_surname, per.forename as contact_forename,
addr.postcode
from sims.sims_person per
inner join sims.sims_residence res on per.person_id = res.person_id
inner join sims.sims_address addr on addr.address_id = res.address_id
where addr.street_description='Brick Hill Drive'
order by per.surname, per.forename

person_id   address_id  residence_id contact_surname                                              contact_forename                                             postcode 
----------- ----------- ------------ ------------------------------------------------------------ ------------------------------------------------------------ -------- 
1740        1345        1625         Abbot                                                        Ben                                                          MK417PZ
113         1345        2588         Abbot                                                        Francis                                                      MK417PZ
2794        1565        2795         Abbot                                                        Francis                                                      MK41 7PZ
113         1345        1            Abbot                                                        Francis                                                      MK417PZ
114         1345        2            Abbot                                                        R                                                            MK417PZ
2795        1565        2796         Abbot                                                        R                                                            MK41 7PZ
114         1345        2589         Abbot                                                        R                                                            MK417PZ

-- After Fix, reset the database and import Ben Abbot again.

-- Address is recognised and not duplicated

address_id  house_number                             postcode 
----------- ---------------------------------------- -------- 
1345        22                                       MK417PZ

-- Contacts aren't duplicated

person_id   address_id  residence_id contact_surname                                              contact_forename                                             postcode 
----------- ----------- ------------ ------------------------------------------------------------ ------------------------------------------------------------ -------- 
1740        1345        1625         Abbot                                                        Ben                                                          MK417PZ
113         1345        2588         Abbot                                                        Francis                                                      MK417PZ
113         1345        1            Abbot                                                        Francis                                                      MK417PZ
114         1345        2            Abbot                                                        R                                                            MK417PZ
114         1345        2589         Abbot                                                        R                                                            MK417PZ

-- Note the original database has two residency records for the same address, one work and one home for these contacts.


-- Unit Test for CR27917
-- Lisa Passfield
-- 24th Feb 2005
-- Mismatching mother when importing new pupil with same address and contacts as existing pupil

-- Add new pupil with same details as existing one with same contacts.
exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<MatchTag UPN="Q369874125896" Surname="Ahmed1" Forename="Mohan1" DOB="1999-01-05" Gender="M"
 FormerUPN="" FormerSurname="">
</MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1

exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<StudentContact>
 <MatchTag UPN="Q369874125896" Surname="Ahmed1" Forename="Mohan1" DOB="1999-01-05" Gender="M" FormerUPN="" FormerSurname=""></MatchTag>
 <Contacts>
  <ContactDetails>
   <Contact Order="2" Title="Mrs" Surname="Ahmed" Forename="" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
   <Address Apartment="" PAON="201,Flat 6" StreetDes="Charles Darwin Centre" District="" Town="East Town" County="Eastshire" Country="" PostCode=""></Address>
   <Phone PhoneType="H" PhoneNo="01245 741123"></Phone>
   <Phone PhoneType="W" PhoneNo="01345 556326"></Phone>
  </ContactDetails>
  <ContactDetails>
   <Contact Order="1" Title="Mr" Surname="Ahmed" Forename="Edwin" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact>
   <Address Apartment="" PAON="201,Flat 6" StreetDes="Charles Darwin Centre" District="" Town="East Town" County="Eastshire" Country="" PostCode=""></Address>
   <Phone PhoneType="H" PhoneNo="01245 741123"></Phone>
   <Phone PhoneType="W" PhoneNo="01345 556311"></Phone>
  </ContactDetails>
 </Contacts>
</StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?>
<data>
 <row UPN=''Q369874125896'' Surname=''Ahmed1'' Forename=''Mohan1'' DOB=''1999-01-05T00:00:00'' Gender=''M'' PersonId=''1546'' MatchFound=''F'' />
</data>', @on_roll = 'T'


-- Match on Gender if present in the XML
-- Lisa P 25th Feb 2005

-- Import new pupil as sibling to existing pupil
exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?>
<Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<MatchTag UPN="U854712563265" Surname="ALLCROFT5" Forename="Catherine5" DOB="1996-12-21" Gender="F"
 FormerUPN="V820200100020" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1

exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?>
 <Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
 <StudentContact>
 <MatchTag UPN="U854712563265" Surname="ALLCROFT5" Forename="Catherine5" DOB="1996-12-21" Gender="F"
  FormerUPN="V820200100020" FormerSurname=""></MatchTag>
 <Contacts>
  <ContactDetails>
   <Contact Order="1" Title="Mr" Surname="ALLCROFT" Forename="" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder="N"></Contact>
   <Address Apartment="" PAON="63" StreetDes="Adforton" District="Charlbury" Town="Shooters Hill" County="Rapshire" Country="" PostCode=""></Address>
   <Phone PhoneType="H" PhoneNo="297765"></Phone>
   <Phone PhoneType="W" PhoneNo="854662"></Phone>
  </ContactDetails>
  <ContactDetails>
   <Contact Order="2" Title="Mrs" Surname="ALLCROFT" Forename="" Gender="F" RelationShip="STP" Responsibility="true" CourtOrder="N"></Contact>
   <Address Apartment="" PAON="63" StreetDes="Adforton" District="Charlbury" Town="Shooters Hill" County="Rapshire" Country="" PostCode=""></Address>
   <Phone PhoneType="H" PhoneNo="297765"></Phone>
   <Phone PhoneType="W" PhoneNo="297765"></Phone>
  </ContactDetails>
 </Contacts>
 </StudentContact>
 </Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?>
 <data>
  <row UPN=''U854712563265'' Surname=''ALLCROFT5'' Forename=''Catherine5'' DOB=''1996-12-21T00:00:00'' Gender=''F''
  PersonId=''1542'' MatchFound=''T'' />
 </data>', @on_roll = 'T'


-- Unit Test for CR28464
-- Importing blank prioriy as 0, it should be NULL

-- Import existing student with new contacts

exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><StudentContact><MatchTag UPN="G820432103006" Surname="Ablett" Forename="Michael" DOB="1991-12-29" Gender="M" FormerUPN="" FormerSurname=""></MatchTag><Contacts><ContactDetails>
<Contact Order="" Title="Mr" Surname="Ablett" Forename="Lance" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" PAON="31" StreetDes="Castle Foregate" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address><Phone PhoneType="H" PhoneNo="847998"></Phone><Phone PhoneType="W" PhoneNo="878665"></Phone></ContactDetails><ContactDetails>
<Contact Order="1" Title="Mrs" Surname="Ablett" Forename="Florence" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact><Address Apartment="" PAON="31" StreetDes="Castle Foregate" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address><Phone PhoneType="H" PhoneNo="847998"></Phone><Phone PhoneType="W" PhoneNo="850223"></Phone></ContactDetails></Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data>
 <row UPN=''G820432103006'' Surname=''Ablett'' Forename=''Michael'' DOB=''1991-12-29T00:00:00'' Gender=''M'' PersonId=''2521'' MatchFound=''T'' /></data>', @on_roll = 'T'

-- Before results include 0 priority
select * from sims.stud_relation rel where student_id = 2521

relation_id relation_type_id student_id  contact_id  parental_responsibility priority legal_order correspondence pupil_report copy_bills status_id   
----------- ---------------- ----------- ----------- ----------------------- -------- ----------- -------------- ------------ ---------- ----------- 
1936        6                2521        2797        T                       0        F           T              T            T          NULL
1937        7                2521        2798        T                       1        F           T              T            T          NULL

-- Delete contacts and reimport
-- Results show null priority
relation_id relation_type_id student_id  contact_id  parental_responsibility priority legal_order correspondence pupil_report copy_bills status_id   
----------- ---------------- ----------- ----------- ----------------------- -------- ----------- -------------- ------------ ---------- ----------- 
1938        6                2521        2797        T                       NULL     F           T              T            T          NULL
1939        7                2521        2798        T                       1        F           T              T            T          NULL


-- Unit test for CR26910
-- By Lisa Passfield
-- 20th May 1005

-- Have moved address matching code to separate procedure to share with student import script
-- Detailed unit tests are contain in ctf_pia_CTFImport_SaveAddresses

exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var"><MatchTag UPN="U820432190122" Surname="Abbot" Forename="Ben" DOB="1986-01-17" Gender="M" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1

exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<StudentContact>
<MatchTag UPN="U820432190122" Surname="Abbot" Forename="Ben" DOB="1986-01-17" Gender="M" FormerUPN="" FormerSurname=""></MatchTag>
<Contacts>
<ContactDetails>
<Contact Order="2" Title="Mr" Surname="Abbot" Forename="Francis" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact>
<Address Apartment="" PAON="22" StreetDes="Brick Hill Drive" District="Rainham" Town="EAST TOWN" County="Eastshire" Country="" PostCode="MK41 7PZ"></Address>
<Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0398 987234"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone>
</ContactDetails>
<ContactDetails>
<Contact Order="1" Title="Mrs" Surname="Abbot1" Forename="Abby" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
<Address Apartment="" PAON="22" StreetDes="Brick Hill Drive" District="Rainham" Town="EAST TOWN" County="Eastshire" Country="" PostCode="MK41 7PZ"></Address>
<Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0378 984326"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone>
</ContactDetails>
<ContactDetails>
<Contact Order="1" Title="Mrs" Surname="Abbot2" Forename="Barbara" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
<Address Apartment="" HouseName="" HouseNo="57" StreetDes="Douglas Crescent" District="Houghton Regis" Town="Dunstable" County="Bedfordshire" Country="" PostCode="LU5 1PQ"></Address>
<Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0378 984326"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone>
</ContactDetails>
<ContactDetails>
<Contact Order="1" Title="Mrs" Surname="Abbot3" Forename="R" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
<Address Apartment="" HouseName="" HouseNo="95" StreetDes="The Street" District="The Locality" Town="The Town" County="Bedfordshire" Country="" PostCode="111111"></Address>
<Phone PhoneType="F" PhoneNo="456 10910"></Phone><Phone PhoneType="H" PhoneNo="456 10910"></Phone><Phone PhoneType="M" PhoneNo="0378 984326"></Phone><Phone PhoneType="W" PhoneNo="456 10910"></Phone>
</ContactDetails>
</Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?>
<data>
 <row UPN=''U820432190122'' Surname=''Abbot'' Forename=''Ben'' DOB=''1986-01-17T00:00:00'' Gender=''M'' PersonId=''3042'' MatchFound=''T'' />
</data>', @on_roll = 'T'

-- Test 1: - Import existing contact with same address

-- Test 2: - Import new contact with existing address

-- Test 3: - Import new contact with new address


-- Test for CR32854 - set priority order to 1 if 0 or null
-- One contact surname is blank and won't

-- Add student
exec sims.db_p_instance_init
exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
 <MatchTag UPN="P555555555555" Surname="Priority" Forename="Order Test" DOB="1994-03-23" Gender="F" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1
exec sims.db_p_instance_drop

-- Add contacts
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<StudentContact><MatchTag UPN="P555555555555" Surname="Priority" Forename="Order Test" DOB="1994-03-23" Gender="F" FormerUPN="" FormerSurname=""></MatchTag>
<Contacts>
 <ContactDetails>
  <Contact Order="" Title="Mr" Surname="" Forename="" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact>
  <Address Apartment="" PAON="10" StreetDes="Meadow Farm Drive" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address>
  <Phone PhoneType="H" PhoneNo="857993"></Phone>
 </ContactDetails>
 <ContactDetails>
  <Contact Order="0" Title="Mrs" Surname="ARKLE" Forename="" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
  <Address Apartment="" PAON="10" StreetDes="Meadow Farm Drive" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address>
  <Phone PhoneType="H" PhoneNo="857993"></Phone>
  <Phone PhoneType="W" PhoneNo="857993"></Phone>
 </ContactDetails>
</Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data></data>', @on_roll = 'T'

-- Test for CR????? - contact surname is empty string
-- Must not import contacts with missing surnames and should report an exception
-- No exception for missing or 0 priority will be reported because if surname is blank the contact will be deleted from temp table.

-- Add student
exec sims.db_p_instance_init
exec sims.ctf_pix_CTFImport_UpdateMatchTag @student_xml = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
 <MatchTag UPN="Y111111111111" Surname="MissingContactSurname" Forename="Test" DOB="1994-03-16" Gender="F" FormerUPN="" FormerSurname=""></MatchTag></Root>', @OnRollFlag = 'T', @base_group_id = -1
exec sims.db_p_instance_drop

-- Add contacts
exec sims.ctf_pix_CTFImport_SaveStudentContact @StudentContactsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<StudentContact><MatchTag UPN="Y111111111111" Surname="MissingContactSurname" Forename="Test" DOB="1994-03-16" Gender="F" FormerUPN="" FormerSurname=""></MatchTag>
<Contacts>
 <ContactDetails>
  <Contact Order="1" Title="Mr" Surname="" Forename="" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder=""></Contact>
  <Address Apartment="" PAON="10" StreetDes="Meadow Farm Drive" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address>
  <Phone PhoneType="H" PhoneNo="857993"></Phone>
 </ContactDetails>
 <ContactDetails>
  <Contact Order="" Title="Mrs" Surname="" Forename="" Gender="F" RelationShip="PAM" Responsibility="true" CourtOrder=""></Contact>
  <Address Apartment="" PAON="10" StreetDes="Meadow Farm Drive" District="" Town="EAST TOWN" County="Eastshire" Country="" PostCode=""></Address>
  <Phone PhoneType="H" PhoneNo="857993"></Phone>
  <Phone PhoneType="W" PhoneNo="857993"></Phone>
 </ContactDetails>
</Contacts></StudentContact></Root>', @PupilsXML = '<?xml version="1.0" encoding="ISO-8859-1"?><data> <row UPN=''N753159862486'' Surname=''MissingContactSurname'' Forename=''Test'' DOB=''1994-03-23T00:00:00'' Gender=''F'' PersonId=''4367'' MatchFound=''F'' /></data>', @on_roll = 'T'


*/
------------------------------------------------------------------------------------------------------------------


/*

Author: Abhinav Pandey
Date  : 6th July 2009
Dataset: Welsh, Secondary

Perform the test:


exec sims.ctf_pix_CTFImport_SaveStudentContactForVersion5 
@StudentContactsXML='<?xml version="1.0" encoding="ISO-8859-1"?><Root xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:var="urn:var">
<StudentContact>
<MatchTag UPN="G820444405021" Surname="Akhtar" Forename="Rahana" PreferredSurname="Akhtar" PreferredForename="Rahana" DOB="1994-11-11" Gender="F" FormerUPN="E820432191070" FormerSurname="" />
<Contacts>
<ContactDetails>
<Contact Order="1" Title="Mr" Surname="Akhtar" Forename="Sajjad" Gender="M" RelationShip="PAF" Responsibility="true" CourtOrder="N" Email="" /><Address SAON="" PAON="##09######" Street="Waen Lane" Locality="" Town="St Janes" UniquePropertyReferenceNumber="" PostTown="" County="Parkshire" Easting="" Northing="" PostCode="SL17 5BH" ZipCode="" Country="United Kingdom" />
<Phone PhoneType="H" PhoneNo="682719" /><Phone PhoneType="W" PhoneNo="682719" />
</ContactDetails>
</Contacts>
</StudentContact><Errors /></Root>',
@PupilsXML='<?xml version="1.0" encoding="ISO-8859-1"?><data> <row UPN=''G820444405021'' Surname=''Akhtar'' Forename=''Rahana'' PreferredSurname=''Akhtar'' PreferredForename=''Rahana'' DOB=''1994-11-11T00:00:00'' Gender=''F'' PersonId=''6301'' MatchFound=''T'' /></data>',@on_roll='T'


Results:

Imported w/o error.

upn           surname                                                      forename                                                     dob                     gender person_id   errormsg
------------- ------------------------------------------------------------ ------------------------------------------------------------ ----------------------- ------ ----------- --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------



*/

















-- END PATCH SCRIPT 1
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	23971,
	1,
	'T',
	'When importing  CTF Contact data is overwritten for unrelated Contacts. This patch resolves the issue.',
	'U',
	GetDate()
)

